import sys
import math
import subprocess
import numpy as np
import pandas as pd
import os.path

class Magpie:
    """
    This class creates an object which can be used to generate Magpie
    features (https://bitbucket.org/wolverton/magpie/). Several default
    parameters are set here which can be overridden using setter functions.
    """

    def __init__(self):
        # Set path to Magpie.jar
        self.magpie_path = "../resources/magpie"

        # Check if file Magpie.jar exists in magpie_path. Throw error otherwise.
        magpie_jar = self.magpie_path+"/Magpie.jar"
        if (not os.path.isfile(magpie_jar)):
            print "File Magpie.jar not located at {}".format(magpie_jar)
            print "Make sure it is located there before proceeding."
            sys.exit(1)

        # Set path to lookup-data directory
        self.lookup_path = "../resources/magpie/lookup-data"

        # Check if the directory lookup-data exists. Throw error otherwise.
        if (not os.path.isdir(self.lookup_path)):
            print "Directory lookup-data not located at {}".format(
                self.lookup_path)
            print "Make sure it is located there before proceeding."
            sys.exit(1)

        # Set tolerances
        self.atol = 1E-10
        self.rtol = 1E-6

    def get_features(self, composition_file_str, file_type='csv',
                     verbose=False):
        """
        This function computes the features as described in the article
        Ward, L., et. al.. npj Computational Materials. 2 (2016), 16028
        and using Magpie (https://bitbucket.org/wolverton/magpie/). The
        function reads the element compositions from the input file
        composition_file_str located in the datasets subdirectory
        within the magpie directory. The function creates a script file
        that is used as input for magpie and saves it in the examples
        subdirectory within the magpie directory. Then it runs magpie
        with the input script file and generates corresponding features.
        Features and feature headers are saved to a file as well as returned as
        python lists.

        :parameter composition_file_str:
        Name of the input file that contains the compositions of materials
        in a csv format. The file itself should be of a specific format.
        The first row contains the header information followed by rows
        containing the composition information of the materials. The last
        column contains dummy values just because Magpie requires that it
        be present. Once this function is implemented completely in python
        the dummy column need not exist as part of the input file. An
        example of the contents of a composition_file_str is given below:

        name dummy_column
        Fe,2.0,O,3.0, 1.0
        Na,1.0,Cl,1.0, 1.0
        Sc,4.0,Si,1.0,Al,1.0,C,1.0,N,1.0, 1.0

        :parameter verbose:
        Flag to be used mainly for debugging purposes as it prints out a lot of
        information. Default value is False.

        :parameter file_type:
        String that denotes the type of file used as input for the function,
        i.e., the type of composition_file_str. Default is 'csv'.

        :return: features
        Feature headers and values as a pandas data frame
        """

        # Set the java command
        cmd_str = "java -cp {0}/Magpie.jar example {0}/{1} {2}".format(
            self.magpie_path, composition_file_str, self.lookup_path)

        # Add verbose flag if necessary
        if (verbose):
            cmd_str += " -v"
            print cmd_str

        # Pipe output of Java to python subprocess
        process = subprocess.Popen(cmd_str, stdout=subprocess.PIPE,
                                   stderr=subprocess.PIPE, shell=True)
        out, err = process.communicate()

        feature_values = []
        feature_headers = []

        if (verbose):
            print "Printing from Python"
            print out

        # Process output to extract feature headers and values
        lines = out.splitlines()

        for i in xrange(len(lines)):
            if ("headers start" in lines[i]):
                feature_headers = lines[i+1].strip().split()
            if ("values start" in lines[i]):
                j = i+1
                while ("values end" not in lines[j]):
                    feature_values.append(map(float,lines[j].strip().split()))
                    j = j+1
                break
        features = pd.DataFrame.from_records(feature_values,
                                             columns=feature_headers)
        # print features
        return features

    def test_example(self):
        # Use example.csv file to get features from magpie
        f1_df = self.get_features("example.csv", 'csv', False)
        f1_values = f1_df.values.tolist()
        f1_headers = list(f1_df)

        # Hard-coded values for example.csv and default magpie settings
        feat_headers = ['NComp', 'Comp_L2Norm', 'Comp_L3Norm', 'Comp_L5Norm',
                        'Comp_L7Norm', 'Comp_L10Norm', 'mean_Number',
                        'maxdiff_Number', 'dev_Number', 'max_Number',
                        'min_Number', 'most_Number', 'mean_MendeleevNumber',
                        'maxdiff_MendeleevNumber', 'dev_MendeleevNumber',
                        'max_MendeleevNumber', 'min_MendeleevNumber',
                        'most_MendeleevNumber', 'mean_AtomicWeight',
                        'maxdiff_AtomicWeight', 'dev_AtomicWeight',
                        'max_AtomicWeight', 'min_AtomicWeight',
                        'most_AtomicWeight', 'mean_MeltingT',
                        'maxdiff_MeltingT','dev_MeltingT', 'max_MeltingT',
                        'min_MeltingT','most_MeltingT', 'mean_Column',
                        'maxdiff_Column','dev_Column', 'max_Column',
                        'min_Column', 'most_Column','mean_Row', 'maxdiff_Row',
                        'dev_Row', 'max_Row', 'min_Row', 'most_Row',
                        'mean_CovalentRadius', 'maxdiff_CovalentRadius',
                        'dev_CovalentRadius', 'max_CovalentRadius',
                        'min_CovalentRadius', 'most_CovalentRadius',
                        'mean_Electronegativity', 'maxdiff_Electronegativity',
                        'dev_Electronegativity', 'max_Electronegativity',
                        'min_Electronegativity', 'most_Electronegativity',
                        'mean_NsValence','maxdiff_NsValence', 'dev_NsValence',
                        'max_NsValence', 'min_NsValence', 'most_NsValence',
                        'mean_NpValence', 'maxdiff_NpValence', 'dev_NpValence',
                        'max_NpValence', 'min_NpValence', 'most_NpValence',
                        'mean_NdValence', 'maxdiff_NdValence', 'dev_NdValence',
                        'max_NdValence', 'min_NdValence', 'most_NdValence',
                        'mean_NfValence', 'maxdiff_NfValence', 'dev_NfValence',
                        'max_NfValence', 'min_NfValence', 'most_NfValence',
                        'mean_NValance', 'maxdiff_NValance', 'dev_NValance',
                        'max_NValance', 'min_NValance', 'most_NValance',
                        'mean_NsUnfilled', 'maxdiff_NsUnfilled',
                        'dev_NsUnfilled', 'max_NsUnfilled', 'min_NsUnfilled',
                        'most_NsUnfilled', 'mean_NpUnfilled',
                        'maxdiff_NpUnfilled', 'dev_NpUnfilled',
                        'max_NpUnfilled', 'min_NpUnfilled','most_NpUnfilled',
                        'mean_NdUnfilled', 'maxdiff_NdUnfilled',
                        'dev_NdUnfilled', 'max_NdUnfilled', 'min_NdUnfilled',
                        'most_NdUnfilled', 'mean_NfUnfilled',
                        'maxdiff_NfUnfilled', 'dev_NfUnfilled',
                        'max_NfUnfilled', 'min_NfUnfilled', 'most_NfUnfilled',
                        'mean_NUnfilled', 'maxdiff_NUnfilled', 'dev_NUnfilled',
                        'max_NUnfilled', 'min_NUnfilled', 'most_NUnfilled',
                        'mean_GSvolume_pa', 'maxdiff_GSvolume_pa',
                        'dev_GSvolume_pa', 'max_GSvolume_pa', 'min_GSvolume_pa',
                        'most_GSvolume_pa', 'mean_GSbandgap',
                        'maxdiff_GSbandgap', 'dev_GSbandgap', 'max_GSbandgap',
                        'min_GSbandgap', 'most_GSbandgap', 'mean_GSmagmom',
                        'maxdiff_GSmagmom', 'dev_GSmagmom', 'max_GSmagmom',
                        'min_GSmagmom', 'most_GSmagmom',
                        'mean_SpaceGroupNumber', 'maxdiff_SpaceGroupNumber',
                        'dev_SpaceGroupNumber', 'max_SpaceGroupNumber',
                        'min_SpaceGroupNumber', 'most_SpaceGroupNumber',
                        'frac_sValence', 'frac_pValence', 'frac_dValence',
                        'frac_fValence', 'CanFormIonic', 'MaxIonicChar',
                        'MeanIonicChar']

        feat_values = [[1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        9.2000000e+01,0.0000000e+00,0.0000000e+00,9.2000000e+01,
                        9.2000000e+01,9.2000000e+01,1.0079400e+00,0.0000000e+00,
                        0.0000000e+00,1.0079400e+00,1.0079400e+00,1.0079400e+00,
                        1.4010000e+01,0.0000000e+00,0.0000000e+00,1.4010000e+01,
                        1.4010000e+01,1.4010000e+01,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,3.1000000e+01,0.0000000e+00,
                        0.0000000e+00,3.1000000e+01,3.1000000e+01,3.1000000e+01,
                        2.2000000e+00,0.0000000e+00,0.0000000e+00,2.2000000e+00,
                        2.2000000e+00,2.2000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,6.6150000e+00,0.0000000e+00,
                        0.0000000e+00,6.6150000e+00,6.6150000e+00,6.6150000e+00,
                        7.8530000e+00,0.0000000e+00,0.0000000e+00,7.8530000e+00,
                        7.8530000e+00,7.8530000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        9.8000000e+01,0.0000000e+00,0.0000000e+00,9.8000000e+01,
                        9.8000000e+01,9.8000000e+01,4.0026020e+00,0.0000000e+00,
                        0.0000000e+00,4.0026020e+00,4.0026020e+00,4.0026020e+00,
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),1.8000000e+01,0.0000000e+00,
                        0.0000000e+00,1.8000000e+01,1.8000000e+01,1.8000000e+01,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,2.8000000e+01,0.0000000e+00,
                        0.0000000e+00,2.8000000e+01,2.8000000e+01,2.8000000e+01,
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.2305000e+01,0.0000000e+00,
                        0.0000000e+00,1.2305000e+01,1.2305000e+01,1.2305000e+01,
                        1.8098000e+01,0.0000000e+00,0.0000000e+00,1.8098000e+01,
                        1.8098000e+01,1.8098000e+01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        float('nan'),float('nan')],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,6.9410000e+00,0.0000000e+00,
                        0.0000000e+00,6.9410000e+00,6.9410000e+00,6.9410000e+00,
                        4.5369000e+02,0.0000000e+00,0.0000000e+00,4.5369000e+02,
                        4.5369000e+02,4.5369000e+02,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,1.2800000e+02,0.0000000e+00,
                        0.0000000e+00,1.2800000e+02,1.2800000e+02,1.2800000e+02,
                        9.8000000e-01,0.0000000e+00,0.0000000e+00,9.8000000e-01,
                        9.8000000e-01,9.8000000e-01,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.6593333e+01,0.0000000e+00,
                        0.0000000e+00,1.6593333e+01,1.6593333e+01,1.6593333e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2900000e+02,0.0000000e+00,0.0000000e+00,2.2900000e+02,
                        2.2900000e+02,2.2900000e+02,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,4.0000000e+00,
                        6.7000000e+01,0.0000000e+00,0.0000000e+00,6.7000000e+01,
                        6.7000000e+01,6.7000000e+01,9.0121820e+00,0.0000000e+00,
                        0.0000000e+00,9.0121820e+00,9.0121820e+00,9.0121820e+00,
                        1.5600000e+03,0.0000000e+00,0.0000000e+00,1.5600000e+03,
                        1.5600000e+03,1.5600000e+03,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,9.6000000e+01,0.0000000e+00,
                        0.0000000e+00,9.6000000e+01,9.6000000e+01,9.6000000e+01,
                        1.5700000e+00,0.0000000e+00,0.0000000e+00,1.5700000e+00,
                        1.5700000e+00,1.5700000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.8900000e+00,0.0000000e+00,
                        0.0000000e+00,7.8900000e+00,7.8900000e+00,7.8900000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        7.2000000e+01,0.0000000e+00,0.0000000e+00,7.2000000e+01,
                        7.2000000e+01,7.2000000e+01,1.0811000e+01,0.0000000e+00,
                        0.0000000e+00,1.0811000e+01,1.0811000e+01,1.0811000e+01,
                        2.3480000e+03,0.0000000e+00,0.0000000e+00,2.3480000e+03,
                        2.3480000e+03,2.3480000e+03,1.3000000e+01,0.0000000e+00,
                        0.0000000e+00,1.3000000e+01,1.3000000e+01,1.3000000e+01,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,8.4000000e+01,0.0000000e+00,
                        0.0000000e+00,8.4000000e+01,8.4000000e+01,8.4000000e+01,
                        2.0400000e+00,0.0000000e+00,0.0000000e+00,2.0400000e+00,
                        2.0400000e+00,2.0400000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,7.1725000e+00,0.0000000e+00,
                        0.0000000e+00,7.1725000e+00,7.1725000e+00,7.1725000e+00,
                        1.5240000e+00,0.0000000e+00,0.0000000e+00,1.5240000e+00,
                        1.5240000e+00,1.5240000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.6600000e+02,0.0000000e+00,0.0000000e+00,1.6600000e+02,
                        1.6600000e+02,1.6600000e+02,6.6666667e-01,3.3333333e-01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,6.0000000e+00,0.0000000e+00,
                        0.0000000e+00,6.0000000e+00,6.0000000e+00,6.0000000e+00,
                        7.7000000e+01,0.0000000e+00,0.0000000e+00,7.7000000e+01,
                        7.7000000e+01,7.7000000e+01,1.2010700e+01,0.0000000e+00,
                        0.0000000e+00,1.2010700e+01,1.2010700e+01,1.2010700e+01,
                        3.8230000e+03,0.0000000e+00,0.0000000e+00,3.8230000e+03,
                        3.8230000e+03,3.8230000e+03,1.4000000e+01,0.0000000e+00,
                        0.0000000e+00,1.4000000e+01,1.4000000e+01,1.4000000e+01,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,7.6000000e+01,0.0000000e+00,
                        0.0000000e+00,7.6000000e+01,7.6000000e+01,7.6000000e+01,
                        2.5500000e+00,0.0000000e+00,0.0000000e+00,2.5500000e+00,
                        2.5500000e+00,2.5500000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,4.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,4.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,5.6400000e+00,0.0000000e+00,
                        0.0000000e+00,5.6400000e+00,5.6400000e+00,5.6400000e+00,
                        4.4960000e+00,0.0000000e+00,0.0000000e+00,4.4960000e+00,
                        4.4960000e+00,4.4960000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,5.0000000e-01,5.0000000e-01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,7.0000000e+00,
                        8.2000000e+01,0.0000000e+00,0.0000000e+00,8.2000000e+01,
                        8.2000000e+01,8.2000000e+01,1.4006700e+01,0.0000000e+00,
                        0.0000000e+00,1.4006700e+01,1.4006700e+01,1.4006700e+01,
                        6.3050000e+01,0.0000000e+00,0.0000000e+00,6.3050000e+01,
                        6.3050000e+01,6.3050000e+01,1.5000000e+01,0.0000000e+00,
                        0.0000000e+00,1.5000000e+01,1.5000000e+01,1.5000000e+01,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,7.1000000e+01,0.0000000e+00,
                        0.0000000e+00,7.1000000e+01,7.1000000e+01,7.1000000e+01,
                        3.0400000e+00,0.0000000e+00,0.0000000e+00,3.0400000e+00,
                        3.0400000e+00,3.0400000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,1.4768750e+01,0.0000000e+00,
                        0.0000000e+00,1.4768750e+01,1.4768750e+01,1.4768750e+01,
                        6.4370000e+00,0.0000000e+00,0.0000000e+00,6.4370000e+00,
                        6.4370000e+00,6.4370000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,4.0000000e-01,6.0000000e-01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,8.0000000e+00,0.0000000e+00,
                        0.0000000e+00,8.0000000e+00,8.0000000e+00,8.0000000e+00,
                        8.7000000e+01,0.0000000e+00,0.0000000e+00,8.7000000e+01,
                        8.7000000e+01,8.7000000e+01,1.5999400e+01,0.0000000e+00,
                        0.0000000e+00,1.5999400e+01,1.5999400e+01,1.5999400e+01,
                        5.4800000e+01,0.0000000e+00,0.0000000e+00,5.4800000e+01,
                        5.4800000e+01,5.4800000e+01,1.6000000e+01,0.0000000e+00,
                        0.0000000e+00,1.6000000e+01,1.6000000e+01,1.6000000e+01,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,6.6000000e+01,0.0000000e+00,
                        0.0000000e+00,6.6000000e+01,6.6000000e+01,6.6000000e+01,
                        3.4400000e+00,0.0000000e+00,0.0000000e+00,3.4400000e+00,
                        3.4400000e+00,3.4400000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,6.0000000e+00,0.0000000e+00,
                        0.0000000e+00,6.0000000e+00,6.0000000e+00,6.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,9.1050000e+00,0.0000000e+00,
                        0.0000000e+00,9.1050000e+00,9.1050000e+00,9.1050000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.2000000e+01,0.0000000e+00,0.0000000e+00,1.2000000e+01,
                        1.2000000e+01,1.2000000e+01,3.3333333e-01,6.6666667e-01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,9.0000000e+00,0.0000000e+00,
                        0.0000000e+00,9.0000000e+00,9.0000000e+00,9.0000000e+00,
                        9.3000000e+01,0.0000000e+00,0.0000000e+00,9.3000000e+01,
                        9.3000000e+01,9.3000000e+01,1.8998403e+01,0.0000000e+00,
                        0.0000000e+00,1.8998403e+01,1.8998403e+01,1.8998403e+01,
                        5.3500000e+01,0.0000000e+00,0.0000000e+00,5.3500000e+01,
                        5.3500000e+01,5.3500000e+01,1.7000000e+01,0.0000000e+00,
                        0.0000000e+00,1.7000000e+01,1.7000000e+01,1.7000000e+01,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,5.7000000e+01,0.0000000e+00,
                        0.0000000e+00,5.7000000e+01,5.7000000e+01,5.7000000e+01,
                        3.9800000e+00,0.0000000e+00,0.0000000e+00,3.9800000e+00,
                        3.9800000e+00,3.9800000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,7.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,9.7075000e+00,0.0000000e+00,
                        0.0000000e+00,9.7075000e+00,9.7075000e+00,9.7075000e+00,
                        1.9700000e+00,0.0000000e+00,0.0000000e+00,1.9700000e+00,
                        1.9700000e+00,1.9700000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.5000000e+01,0.0000000e+00,0.0000000e+00,1.5000000e+01,
                        1.5000000e+01,1.5000000e+01,2.8571429e-01,7.1428571e-01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        9.9000000e+01,0.0000000e+00,0.0000000e+00,9.9000000e+01,
                        9.9000000e+01,9.9000000e+01,2.0179100e+01,0.0000000e+00,
                        0.0000000e+00,2.0179100e+01,2.0179100e+01,2.0179100e+01,
                        2.4560000e+01,0.0000000e+00,0.0000000e+00,2.4560000e+01,
                        2.4560000e+01,2.4560000e+01,1.8000000e+01,0.0000000e+00,
                        0.0000000e+00,1.8000000e+01,1.8000000e+01,1.8000000e+01,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,5.8000000e+01,0.0000000e+00,
                        0.0000000e+00,5.8000000e+01,5.8000000e+01,5.8000000e+01,
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,8.0000000e+00,0.0000000e+00,
                        0.0000000e+00,8.0000000e+00,8.0000000e+00,8.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.2640000e+01,0.0000000e+00,
                        0.0000000e+00,1.2640000e+01,1.2640000e+01,1.2640000e+01,
                        1.3088000e+01,0.0000000e+00,0.0000000e+00,1.3088000e+01,
                        1.3088000e+01,1.3088000e+01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,2.5000000e-01,7.5000000e-01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,float('nan'),
                        float('nan')],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.1000000e+01,0.0000000e+00,
                        0.0000000e+00,1.1000000e+01,1.1000000e+01,1.1000000e+01,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,2.2989769e+01,0.0000000e+00,
                        0.0000000e+00,2.2989769e+01,2.2989769e+01,2.2989769e+01,
                        3.7087000e+02,0.0000000e+00,0.0000000e+00,3.7087000e+02,
                        3.7087000e+02,3.7087000e+02,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,1.6600000e+02,0.0000000e+00,
                        0.0000000e+00,1.6600000e+02,1.6600000e+02,1.6600000e+02,
                        9.3000000e-01,0.0000000e+00,0.0000000e+00,9.3000000e-01,
                        9.3000000e-01,9.3000000e-01,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,2.9243333e+01,0.0000000e+00,
                        0.0000000e+00,2.9243333e+01,2.9243333e+01,2.9243333e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2900000e+02,0.0000000e+00,0.0000000e+00,2.2900000e+02,
                        2.2900000e+02,2.2900000e+02,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.2000000e+01,0.0000000e+00,
                        0.0000000e+00,1.2000000e+01,1.2000000e+01,1.2000000e+01,
                        6.8000000e+01,0.0000000e+00,0.0000000e+00,6.8000000e+01,
                        6.8000000e+01,6.8000000e+01,2.4305000e+01,0.0000000e+00,
                        0.0000000e+00,2.4305000e+01,2.4305000e+01,2.4305000e+01,
                        9.2300000e+02,0.0000000e+00,0.0000000e+00,9.2300000e+02,
                        9.2300000e+02,9.2300000e+02,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,1.4100000e+02,0.0000000e+00,
                        0.0000000e+00,1.4100000e+02,1.4100000e+02,1.4100000e+02,
                        1.3100000e+00,0.0000000e+00,0.0000000e+00,1.3100000e+00,
                        1.3100000e+00,1.3100000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.2890000e+01,0.0000000e+00,
                        0.0000000e+00,2.2890000e+01,2.2890000e+01,2.2890000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.3000000e+01,0.0000000e+00,
                        0.0000000e+00,1.3000000e+01,1.3000000e+01,1.3000000e+01,
                        7.3000000e+01,0.0000000e+00,0.0000000e+00,7.3000000e+01,
                        7.3000000e+01,7.3000000e+01,2.6981539e+01,0.0000000e+00,
                        0.0000000e+00,2.6981539e+01,2.6981539e+01,2.6981539e+01,
                        9.3347000e+02,0.0000000e+00,0.0000000e+00,9.3347000e+02,
                        9.3347000e+02,9.3347000e+02,1.3000000e+01,0.0000000e+00,
                        0.0000000e+00,1.3000000e+01,1.3000000e+01,1.3000000e+01,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,1.2100000e+02,0.0000000e+00,
                        0.0000000e+00,1.2100000e+02,1.2100000e+02,1.2100000e+02,
                        1.6100000e+00,0.0000000e+00,0.0000000e+00,1.6100000e+00,
                        1.6100000e+00,1.6100000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.6480000e+01,0.0000000e+00,
                        0.0000000e+00,1.6480000e+01,1.6480000e+01,1.6480000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,6.6666667e-01,3.3333333e-01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.4000000e+01,0.0000000e+00,
                        0.0000000e+00,1.4000000e+01,1.4000000e+01,1.4000000e+01,
                        7.8000000e+01,0.0000000e+00,0.0000000e+00,7.8000000e+01,
                        7.8000000e+01,7.8000000e+01,2.8085500e+01,0.0000000e+00,
                        0.0000000e+00,2.8085500e+01,2.8085500e+01,2.8085500e+01,
                        1.6870000e+03,0.0000000e+00,0.0000000e+00,1.6870000e+03,
                        1.6870000e+03,1.6870000e+03,1.4000000e+01,0.0000000e+00,
                        0.0000000e+00,1.4000000e+01,1.4000000e+01,1.4000000e+01,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,1.1100000e+02,0.0000000e+00,
                        0.0000000e+00,1.1100000e+02,1.1100000e+02,1.1100000e+02,
                        1.9000000e+00,0.0000000e+00,0.0000000e+00,1.9000000e+00,
                        1.9000000e+00,1.9000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,4.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,4.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,2.0440000e+01,0.0000000e+00,
                        0.0000000e+00,2.0440000e+01,2.0440000e+01,2.0440000e+01,
                        7.7300000e-01,0.0000000e+00,0.0000000e+00,7.7300000e-01,
                        7.7300000e-01,7.7300000e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2700000e+02,0.0000000e+00,0.0000000e+00,2.2700000e+02,
                        2.2700000e+02,2.2700000e+02,5.0000000e-01,5.0000000e-01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.5000000e+01,0.0000000e+00,
                        0.0000000e+00,1.5000000e+01,1.5000000e+01,1.5000000e+01,
                        8.3000000e+01,0.0000000e+00,0.0000000e+00,8.3000000e+01,
                        8.3000000e+01,8.3000000e+01,3.0973762e+01,0.0000000e+00,
                        0.0000000e+00,3.0973762e+01,3.0973762e+01,3.0973762e+01,
                        3.1730000e+02,0.0000000e+00,0.0000000e+00,3.1730000e+02,
                        3.1730000e+02,3.1730000e+02,1.5000000e+01,0.0000000e+00,
                        0.0000000e+00,1.5000000e+01,1.5000000e+01,1.5000000e+01,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,1.0700000e+02,0.0000000e+00,
                        0.0000000e+00,1.0700000e+02,1.0700000e+02,1.0700000e+02,
                        2.1900000e+00,0.0000000e+00,0.0000000e+00,2.1900000e+00,
                        2.1900000e+00,2.1900000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,2.2570238e+01,0.0000000e+00,
                        0.0000000e+00,2.2570238e+01,2.2570238e+01,2.2570238e+01,
                        1.6250000e+00,0.0000000e+00,0.0000000e+00,1.6250000e+00,
                        1.6250000e+00,1.6250000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,4.0000000e-01,6.0000000e-01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.6000000e+01,0.0000000e+00,
                        0.0000000e+00,1.6000000e+01,1.6000000e+01,1.6000000e+01,
                        8.8000000e+01,0.0000000e+00,0.0000000e+00,8.8000000e+01,
                        8.8000000e+01,8.8000000e+01,3.2065000e+01,0.0000000e+00,
                        0.0000000e+00,3.2065000e+01,3.2065000e+01,3.2065000e+01,
                        3.8836000e+02,0.0000000e+00,0.0000000e+00,3.8836000e+02,
                        3.8836000e+02,3.8836000e+02,1.6000000e+01,0.0000000e+00,
                        0.0000000e+00,1.6000000e+01,1.6000000e+01,1.6000000e+01,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,1.0500000e+02,0.0000000e+00,
                        0.0000000e+00,1.0500000e+02,1.0500000e+02,1.0500000e+02,
                        2.5800000e+00,0.0000000e+00,0.0000000e+00,2.5800000e+00,
                        2.5800000e+00,2.5800000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,6.0000000e+00,0.0000000e+00,
                        0.0000000e+00,6.0000000e+00,6.0000000e+00,6.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,2.5786875e+01,0.0000000e+00,
                        0.0000000e+00,2.5786875e+01,2.5786875e+01,2.5786875e+01,
                        2.2020000e+00,0.0000000e+00,0.0000000e+00,2.2020000e+00,
                        2.2020000e+00,2.2020000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        7.0000000e+01,0.0000000e+00,0.0000000e+00,7.0000000e+01,
                        7.0000000e+01,7.0000000e+01,3.3333333e-01,6.6666667e-01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.7000000e+01,0.0000000e+00,
                        0.0000000e+00,1.7000000e+01,1.7000000e+01,1.7000000e+01,
                        9.4000000e+01,0.0000000e+00,0.0000000e+00,9.4000000e+01,
                        9.4000000e+01,9.4000000e+01,3.5453000e+01,0.0000000e+00,
                        0.0000000e+00,3.5453000e+01,3.5453000e+01,3.5453000e+01,
                        1.7160000e+02,0.0000000e+00,0.0000000e+00,1.7160000e+02,
                        1.7160000e+02,1.7160000e+02,1.7000000e+01,0.0000000e+00,
                        0.0000000e+00,1.7000000e+01,1.7000000e+01,1.7000000e+01,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,1.0200000e+02,0.0000000e+00,
                        0.0000000e+00,1.0200000e+02,1.0200000e+02,1.0200000e+02,
                        3.1600000e+00,0.0000000e+00,0.0000000e+00,3.1600000e+00,
                        3.1600000e+00,3.1600000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,7.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,2.4497500e+01,0.0000000e+00,
                        0.0000000e+00,2.4497500e+01,2.4497500e+01,2.4497500e+01,
                        2.4930000e+00,0.0000000e+00,0.0000000e+00,2.4930000e+00,
                        2.4930000e+00,2.4930000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        6.4000000e+01,0.0000000e+00,0.0000000e+00,6.4000000e+01,
                        6.4000000e+01,6.4000000e+01,2.8571429e-01,7.1428571e-01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.8000000e+01,0.0000000e+00,
                        0.0000000e+00,1.8000000e+01,1.8000000e+01,1.8000000e+01,
                        1.0000000e+02,0.0000000e+00,0.0000000e+00,1.0000000e+02,
                        1.0000000e+02,1.0000000e+02,3.9948000e+01,0.0000000e+00,
                        0.0000000e+00,3.9948000e+01,3.9948000e+01,3.9948000e+01,
                        8.3800000e+01,0.0000000e+00,0.0000000e+00,8.3800000e+01,
                        8.3800000e+01,8.3800000e+01,1.8000000e+01,0.0000000e+00,
                        0.0000000e+00,1.8000000e+01,1.8000000e+01,1.8000000e+01,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,1.0600000e+02,0.0000000e+00,
                        0.0000000e+00,1.0600000e+02,1.0600000e+02,1.0600000e+02,
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,8.0000000e+00,0.0000000e+00,
                        0.0000000e+00,8.0000000e+00,8.0000000e+00,8.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.8540000e+01,0.0000000e+00,
                        0.0000000e+00,2.8540000e+01,2.8540000e+01,2.8540000e+01,
                        9.2600000e+00,0.0000000e+00,0.0000000e+00,9.2600000e+00,
                        9.2600000e+00,9.2600000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,2.5000000e-01,7.5000000e-01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,float('nan'),
                        float('nan')],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.9000000e+01,0.0000000e+00,
                        0.0000000e+00,1.9000000e+01,1.9000000e+01,1.9000000e+01,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,3.9098300e+01,0.0000000e+00,
                        0.0000000e+00,3.9098300e+01,3.9098300e+01,3.9098300e+01,
                        3.3653000e+02,0.0000000e+00,0.0000000e+00,3.3653000e+02,
                        3.3653000e+02,3.3653000e+02,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,2.0300000e+02,0.0000000e+00,
                        0.0000000e+00,2.0300000e+02,2.0300000e+02,2.0300000e+02,
                        8.2000000e-01,0.0000000e+00,0.0000000e+00,8.2000000e-01,
                        8.2000000e-01,8.2000000e-01,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,7.3106667e+01,0.0000000e+00,
                        0.0000000e+00,7.3106667e+01,7.3106667e+01,7.3106667e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2900000e+02,0.0000000e+00,0.0000000e+00,2.2900000e+02,
                        2.2900000e+02,2.2900000e+02,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,2.0000000e+01,0.0000000e+00,
                        0.0000000e+00,2.0000000e+01,2.0000000e+01,2.0000000e+01,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,4.0078000e+01,0.0000000e+00,
                        0.0000000e+00,4.0078000e+01,4.0078000e+01,4.0078000e+01,
                        1.1150000e+03,0.0000000e+00,0.0000000e+00,1.1150000e+03,
                        1.1150000e+03,1.1150000e+03,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.7600000e+02,0.0000000e+00,
                        0.0000000e+00,1.7600000e+02,1.7600000e+02,1.7600000e+02,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.7770000e+01,0.0000000e+00,
                        0.0000000e+00,3.7770000e+01,3.7770000e+01,3.7770000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,2.1000000e+01,0.0000000e+00,
                        0.0000000e+00,2.1000000e+01,2.1000000e+01,2.1000000e+01,
                        1.1000000e+01,0.0000000e+00,0.0000000e+00,1.1000000e+01,
                        1.1000000e+01,1.1000000e+01,4.4955912e+01,0.0000000e+00,
                        0.0000000e+00,4.4955912e+01,4.4955912e+01,4.4955912e+01,
                        1.8140000e+03,0.0000000e+00,0.0000000e+00,1.8140000e+03,
                        1.8140000e+03,1.8140000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.7000000e+02,0.0000000e+00,
                        0.0000000e+00,1.7000000e+02,1.7000000e+02,1.7000000e+02,
                        1.3600000e+00,0.0000000e+00,0.0000000e+00,1.3600000e+00,
                        1.3600000e+00,1.3600000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,2.2235000e+01,0.0000000e+00,
                        0.0000000e+00,2.2235000e+01,2.2235000e+01,2.2235000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,6.3500000e-06,0.0000000e+00,
                        0.0000000e+00,6.3500000e-06,6.3500000e-06,6.3500000e-06,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,6.6666667e-01,0.0000000e+00,
                        3.3333333e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,2.2000000e+01,0.0000000e+00,
                        0.0000000e+00,2.2000000e+01,2.2000000e+01,2.2000000e+01,
                        4.3000000e+01,0.0000000e+00,0.0000000e+00,4.3000000e+01,
                        4.3000000e+01,4.3000000e+01,4.7867000e+01,0.0000000e+00,
                        0.0000000e+00,4.7867000e+01,4.7867000e+01,4.7867000e+01,
                        1.9410000e+03,0.0000000e+00,0.0000000e+00,1.9410000e+03,
                        1.9410000e+03,1.9410000e+03,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,4.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.6000000e+02,0.0000000e+00,
                        0.0000000e+00,1.6000000e+02,1.6000000e+02,1.6000000e+02,
                        1.5400000e+00,0.0000000e+00,0.0000000e+00,1.5400000e+00,
                        1.5400000e+00,1.5400000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,4.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        8.0000000e+00,0.0000000e+00,0.0000000e+00,8.0000000e+00,
                        8.0000000e+00,8.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        8.0000000e+00,0.0000000e+00,0.0000000e+00,8.0000000e+00,
                        8.0000000e+00,8.0000000e+00,1.6690000e+01,0.0000000e+00,
                        0.0000000e+00,1.6690000e+01,1.6690000e+01,1.6690000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.2533333e-05,0.0000000e+00,
                        0.0000000e+00,2.2533333e-05,2.2533333e-05,2.2533333e-05,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,5.0000000e-01,0.0000000e+00,
                        5.0000000e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,2.3000000e+01,0.0000000e+00,
                        0.0000000e+00,2.3000000e+01,2.3000000e+01,2.3000000e+01,
                        4.6000000e+01,0.0000000e+00,0.0000000e+00,4.6000000e+01,
                        4.6000000e+01,4.6000000e+01,5.0941500e+01,0.0000000e+00,
                        0.0000000e+00,5.0941500e+01,5.0941500e+01,5.0941500e+01,
                        2.1830000e+03,0.0000000e+00,0.0000000e+00,2.1830000e+03,
                        2.1830000e+03,2.1830000e+03,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.5300000e+02,0.0000000e+00,
                        0.0000000e+00,1.5300000e+02,1.5300000e+02,1.5300000e+02,
                        1.6300000e+00,0.0000000e+00,0.0000000e+00,1.6300000e+00,
                        1.6300000e+00,1.6300000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,1.3010000e+01,0.0000000e+00,
                        0.0000000e+00,1.3010000e+01,1.3010000e+01,1.3010000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2900000e+02,0.0000000e+00,0.0000000e+00,2.2900000e+02,
                        2.2900000e+02,2.2900000e+02,4.0000000e-01,0.0000000e+00,
                        6.0000000e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,2.4000000e+01,0.0000000e+00,
                        0.0000000e+00,2.4000000e+01,2.4000000e+01,2.4000000e+01,
                        4.9000000e+01,0.0000000e+00,0.0000000e+00,4.9000000e+01,
                        4.9000000e+01,4.9000000e+01,5.1996100e+01,0.0000000e+00,
                        0.0000000e+00,5.1996100e+01,5.1996100e+01,5.1996100e+01,
                        2.1800000e+03,0.0000000e+00,0.0000000e+00,2.1800000e+03,
                        2.1800000e+03,2.1800000e+03,6.0000000e+00,0.0000000e+00,
                        0.0000000e+00,6.0000000e+00,6.0000000e+00,6.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.3900000e+02,0.0000000e+00,
                        0.0000000e+00,1.3900000e+02,1.3900000e+02,1.3900000e+02,
                        1.6600000e+00,0.0000000e+00,0.0000000e+00,1.6600000e+00,
                        1.6600000e+00,1.6600000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,6.0000000e+00,0.0000000e+00,
                        0.0000000e+00,6.0000000e+00,6.0000000e+00,6.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.1190000e+01,0.0000000e+00,
                        0.0000000e+00,1.1190000e+01,1.1190000e+01,1.1190000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2900000e+02,0.0000000e+00,0.0000000e+00,2.2900000e+02,
                        2.2900000e+02,2.2900000e+02,1.6666667e-01,0.0000000e+00,
                        8.3333333e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,2.5000000e+01,0.0000000e+00,
                        0.0000000e+00,2.5000000e+01,2.5000000e+01,2.5000000e+01,
                        5.2000000e+01,0.0000000e+00,0.0000000e+00,5.2000000e+01,
                        5.2000000e+01,5.2000000e+01,5.4938045e+01,0.0000000e+00,
                        0.0000000e+00,5.4938045e+01,5.4938045e+01,5.4938045e+01,
                        1.5190000e+03,0.0000000e+00,0.0000000e+00,1.5190000e+03,
                        1.5190000e+03,1.5190000e+03,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,7.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.3900000e+02,0.0000000e+00,
                        0.0000000e+00,1.3900000e+02,1.3900000e+02,1.3900000e+02,
                        1.5500000e+00,0.0000000e+00,0.0000000e+00,1.5500000e+00,
                        1.5500000e+00,1.5500000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,7.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.0487586e+01,0.0000000e+00,
                        0.0000000e+00,1.0487586e+01,1.0487586e+01,1.0487586e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.1012069e-04,0.0000000e+00,
                        0.0000000e+00,3.1012069e-04,3.1012069e-04,3.1012069e-04,
                        2.1700000e+02,0.0000000e+00,0.0000000e+00,2.1700000e+02,
                        2.1700000e+02,2.1700000e+02,2.8571429e-01,0.0000000e+00,
                        7.1428571e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,2.6000000e+01,0.0000000e+00,
                        0.0000000e+00,2.6000000e+01,2.6000000e+01,2.6000000e+01,
                        5.5000000e+01,0.0000000e+00,0.0000000e+00,5.5000000e+01,
                        5.5000000e+01,5.5000000e+01,5.5845000e+01,0.0000000e+00,
                        0.0000000e+00,5.5845000e+01,5.5845000e+01,5.5845000e+01,
                        1.8110000e+03,0.0000000e+00,0.0000000e+00,1.8110000e+03,
                        1.8110000e+03,1.8110000e+03,8.0000000e+00,0.0000000e+00,
                        0.0000000e+00,8.0000000e+00,8.0000000e+00,8.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.3200000e+02,0.0000000e+00,
                        0.0000000e+00,1.3200000e+02,1.3200000e+02,1.3200000e+02,
                        1.8300000e+00,0.0000000e+00,0.0000000e+00,1.8300000e+00,
                        1.8300000e+00,1.8300000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,6.0000000e+00,0.0000000e+00,
                        0.0000000e+00,6.0000000e+00,6.0000000e+00,6.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,8.0000000e+00,0.0000000e+00,
                        0.0000000e+00,8.0000000e+00,8.0000000e+00,8.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.0730000e+01,0.0000000e+00,
                        0.0000000e+00,1.0730000e+01,1.0730000e+01,1.0730000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.1106628e+00,0.0000000e+00,
                        0.0000000e+00,2.1106628e+00,2.1106628e+00,2.1106628e+00,
                        2.2900000e+02,0.0000000e+00,0.0000000e+00,2.2900000e+02,
                        2.2900000e+02,2.2900000e+02,2.5000000e-01,0.0000000e+00,
                        7.5000000e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,2.7000000e+01,0.0000000e+00,
                        0.0000000e+00,2.7000000e+01,2.7000000e+01,2.7000000e+01,
                        5.8000000e+01,0.0000000e+00,0.0000000e+00,5.8000000e+01,
                        5.8000000e+01,5.8000000e+01,5.8933195e+01,0.0000000e+00,
                        0.0000000e+00,5.8933195e+01,5.8933195e+01,5.8933195e+01,
                        1.7680000e+03,0.0000000e+00,0.0000000e+00,1.7680000e+03,
                        1.7680000e+03,1.7680000e+03,9.0000000e+00,0.0000000e+00,
                        0.0000000e+00,9.0000000e+00,9.0000000e+00,9.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.2600000e+02,0.0000000e+00,
                        0.0000000e+00,1.2600000e+02,1.2600000e+02,1.2600000e+02,
                        1.8800000e+00,0.0000000e+00,0.0000000e+00,1.8800000e+00,
                        1.8800000e+00,1.8800000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,7.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,9.0000000e+00,0.0000000e+00,
                        0.0000000e+00,9.0000000e+00,9.0000000e+00,9.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,1.0245000e+01,0.0000000e+00,
                        0.0000000e+00,1.0245000e+01,1.0245000e+01,1.0245000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.5484712e+00,0.0000000e+00,
                        0.0000000e+00,1.5484712e+00,1.5484712e+00,1.5484712e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,2.2222222e-01,0.0000000e+00,
                        7.7777778e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,2.8000000e+01,0.0000000e+00,
                        0.0000000e+00,2.8000000e+01,2.8000000e+01,2.8000000e+01,
                        6.1000000e+01,0.0000000e+00,0.0000000e+00,6.1000000e+01,
                        6.1000000e+01,6.1000000e+01,5.8693400e+01,0.0000000e+00,
                        0.0000000e+00,5.8693400e+01,5.8693400e+01,5.8693400e+01,
                        1.7280000e+03,0.0000000e+00,0.0000000e+00,1.7280000e+03,
                        1.7280000e+03,1.7280000e+03,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.2400000e+02,0.0000000e+00,
                        0.0000000e+00,1.2400000e+02,1.2400000e+02,1.2400000e+02,
                        1.9100000e+00,0.0000000e+00,0.0000000e+00,1.9100000e+00,
                        1.9100000e+00,1.9100000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,8.0000000e+00,0.0000000e+00,
                        0.0000000e+00,8.0000000e+00,8.0000000e+00,8.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,1.0320000e+01,0.0000000e+00,
                        0.0000000e+00,1.0320000e+01,1.0320000e+01,1.0320000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.9539470e-01,0.0000000e+00,
                        0.0000000e+00,5.9539470e-01,5.9539470e-01,5.9539470e-01,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,2.0000000e-01,0.0000000e+00,
                        8.0000000e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,2.9000000e+01,0.0000000e+00,
                        0.0000000e+00,2.9000000e+01,2.9000000e+01,2.9000000e+01,
                        6.4000000e+01,0.0000000e+00,0.0000000e+00,6.4000000e+01,
                        6.4000000e+01,6.4000000e+01,6.3546000e+01,0.0000000e+00,
                        0.0000000e+00,6.3546000e+01,6.3546000e+01,6.3546000e+01,
                        1.3577700e+03,0.0000000e+00,0.0000000e+00,1.3577700e+03,
                        1.3577700e+03,1.3577700e+03,1.1000000e+01,0.0000000e+00,
                        0.0000000e+00,1.1000000e+01,1.1000000e+01,1.1000000e+01,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.3200000e+02,0.0000000e+00,
                        0.0000000e+00,1.3200000e+02,1.3200000e+02,1.3200000e+02,
                        1.9000000e+00,0.0000000e+00,0.0000000e+00,1.9000000e+00,
                        1.9000000e+00,1.9000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.1000000e+01,0.0000000e+00,
                        0.0000000e+00,1.1000000e+01,1.1000000e+01,1.1000000e+01,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.1070000e+01,0.0000000e+00,
                        0.0000000e+00,1.1070000e+01,1.1070000e+01,1.1070000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,9.0909091e-02,0.0000000e+00,
                        9.0909091e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,3.0000000e+01,0.0000000e+00,
                        0.0000000e+00,3.0000000e+01,3.0000000e+01,3.0000000e+01,
                        6.9000000e+01,0.0000000e+00,0.0000000e+00,6.9000000e+01,
                        6.9000000e+01,6.9000000e+01,6.5380000e+01,0.0000000e+00,
                        0.0000000e+00,6.5380000e+01,6.5380000e+01,6.5380000e+01,
                        6.9268000e+02,0.0000000e+00,0.0000000e+00,6.9268000e+02,
                        6.9268000e+02,6.9268000e+02,1.2000000e+01,0.0000000e+00,
                        0.0000000e+00,1.2000000e+01,1.2000000e+01,1.2000000e+01,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.2200000e+02,0.0000000e+00,
                        0.0000000e+00,1.2200000e+02,1.2200000e+02,1.2200000e+02,
                        1.6500000e+00,0.0000000e+00,0.0000000e+00,1.6500000e+00,
                        1.6500000e+00,1.6500000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.2000000e+01,0.0000000e+00,
                        0.0000000e+00,1.2000000e+01,1.2000000e+01,1.2000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.3960000e+01,0.0000000e+00,
                        0.0000000e+00,1.3960000e+01,1.3960000e+01,1.3960000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,1.6666667e-01,0.0000000e+00,
                        8.3333333e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,3.1000000e+01,0.0000000e+00,
                        0.0000000e+00,3.1000000e+01,3.1000000e+01,3.1000000e+01,
                        7.4000000e+01,0.0000000e+00,0.0000000e+00,7.4000000e+01,
                        7.4000000e+01,7.4000000e+01,6.9723000e+01,0.0000000e+00,
                        0.0000000e+00,6.9723000e+01,6.9723000e+01,6.9723000e+01,
                        3.0291000e+02,0.0000000e+00,0.0000000e+00,3.0291000e+02,
                        3.0291000e+02,3.0291000e+02,1.3000000e+01,0.0000000e+00,
                        0.0000000e+00,1.3000000e+01,1.3000000e+01,1.3000000e+01,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.2200000e+02,0.0000000e+00,
                        0.0000000e+00,1.2200000e+02,1.2200000e+02,1.2200000e+02,
                        1.8100000e+00,0.0000000e+00,0.0000000e+00,1.8100000e+00,
                        1.8100000e+00,1.8100000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.3000000e+01,0.0000000e+00,
                        0.0000000e+00,1.3000000e+01,1.3000000e+01,1.3000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.8857500e+01,0.0000000e+00,
                        0.0000000e+00,1.8857500e+01,1.8857500e+01,1.8857500e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        6.4000000e+01,0.0000000e+00,0.0000000e+00,6.4000000e+01,
                        6.4000000e+01,6.4000000e+01,1.5384615e-01,7.6923077e-02,
                        7.6923077e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,3.2000000e+01,0.0000000e+00,
                        0.0000000e+00,3.2000000e+01,3.2000000e+01,3.2000000e+01,
                        7.9000000e+01,0.0000000e+00,0.0000000e+00,7.9000000e+01,
                        7.9000000e+01,7.9000000e+01,7.2640000e+01,0.0000000e+00,
                        0.0000000e+00,7.2640000e+01,7.2640000e+01,7.2640000e+01,
                        1.2114000e+03,0.0000000e+00,0.0000000e+00,1.2114000e+03,
                        1.2114000e+03,1.2114000e+03,1.4000000e+01,0.0000000e+00,
                        0.0000000e+00,1.4000000e+01,1.4000000e+01,1.4000000e+01,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.2000000e+02,0.0000000e+00,
                        0.0000000e+00,1.2000000e+02,1.2000000e+02,1.2000000e+02,
                        2.0100000e+00,0.0000000e+00,0.0000000e+00,2.0100000e+00,
                        2.0100000e+00,2.0100000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.4000000e+01,0.0000000e+00,
                        0.0000000e+00,1.4000000e+01,1.4000000e+01,1.4000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,4.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,2.3005000e+01,0.0000000e+00,
                        0.0000000e+00,2.3005000e+01,2.3005000e+01,2.3005000e+01,
                        3.8300000e-01,0.0000000e+00,0.0000000e+00,3.8300000e-01,
                        3.8300000e-01,3.8300000e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,1.4285714e-01,1.4285714e-01,
                        7.1428571e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,3.3000000e+01,0.0000000e+00,
                        0.0000000e+00,3.3000000e+01,3.3000000e+01,3.3000000e+01,
                        8.4000000e+01,0.0000000e+00,0.0000000e+00,8.4000000e+01,
                        8.4000000e+01,8.4000000e+01,7.4921600e+01,0.0000000e+00,
                        0.0000000e+00,7.4921600e+01,7.4921600e+01,7.4921600e+01,
                        1.0900000e+03,0.0000000e+00,0.0000000e+00,1.0900000e+03,
                        1.0900000e+03,1.0900000e+03,1.5000000e+01,0.0000000e+00,
                        0.0000000e+00,1.5000000e+01,1.5000000e+01,1.5000000e+01,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.1900000e+02,0.0000000e+00,
                        0.0000000e+00,1.1900000e+02,1.1900000e+02,1.1900000e+02,
                        2.1800000e+00,0.0000000e+00,0.0000000e+00,2.1800000e+00,
                        2.1800000e+00,2.1800000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.5000000e+01,0.0000000e+00,
                        0.0000000e+00,1.5000000e+01,1.5000000e+01,1.5000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,2.2175000e+01,0.0000000e+00,
                        0.0000000e+00,2.2175000e+01,2.2175000e+01,2.2175000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.6600000e+02,0.0000000e+00,0.0000000e+00,1.6600000e+02,
                        1.6600000e+02,1.6600000e+02,1.3333333e-01,2.0000000e-01,
                        6.6666667e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,3.4000000e+01,0.0000000e+00,
                        0.0000000e+00,3.4000000e+01,3.4000000e+01,3.4000000e+01,
                        8.9000000e+01,0.0000000e+00,0.0000000e+00,8.9000000e+01,
                        8.9000000e+01,8.9000000e+01,7.8960000e+01,0.0000000e+00,
                        0.0000000e+00,7.8960000e+01,7.8960000e+01,7.8960000e+01,
                        4.9400000e+02,0.0000000e+00,0.0000000e+00,4.9400000e+02,
                        4.9400000e+02,4.9400000e+02,1.6000000e+01,0.0000000e+00,
                        0.0000000e+00,1.6000000e+01,1.6000000e+01,1.6000000e+01,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.2000000e+02,0.0000000e+00,
                        0.0000000e+00,1.2000000e+02,1.2000000e+02,1.2000000e+02,
                        2.5500000e+00,0.0000000e+00,0.0000000e+00,2.5500000e+00,
                        2.5500000e+00,2.5500000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.6000000e+01,0.0000000e+00,
                        0.0000000e+00,1.6000000e+01,1.6000000e+01,1.6000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,2.5920000e+01,0.0000000e+00,
                        0.0000000e+00,2.5920000e+01,2.5920000e+01,2.5920000e+01,
                        7.9900000e-01,0.0000000e+00,0.0000000e+00,7.9900000e-01,
                        7.9900000e-01,7.9900000e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,1.2500000e-01,2.5000000e-01,
                        6.2500000e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,3.5000000e+01,0.0000000e+00,
                        0.0000000e+00,3.5000000e+01,3.5000000e+01,3.5000000e+01,
                        9.5000000e+01,0.0000000e+00,0.0000000e+00,9.5000000e+01,
                        9.5000000e+01,9.5000000e+01,7.9904000e+01,0.0000000e+00,
                        0.0000000e+00,7.9904000e+01,7.9904000e+01,7.9904000e+01,
                        2.6580000e+02,0.0000000e+00,0.0000000e+00,2.6580000e+02,
                        2.6580000e+02,2.6580000e+02,1.7000000e+01,0.0000000e+00,
                        0.0000000e+00,1.7000000e+01,1.7000000e+01,1.7000000e+01,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.2000000e+02,0.0000000e+00,
                        0.0000000e+00,1.2000000e+02,1.2000000e+02,1.2000000e+02,
                        2.9600000e+00,0.0000000e+00,0.0000000e+00,2.9600000e+00,
                        2.9600000e+00,2.9600000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.7000000e+01,0.0000000e+00,
                        0.0000000e+00,1.7000000e+01,1.7000000e+01,1.7000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,2.9480000e+01,0.0000000e+00,
                        0.0000000e+00,2.9480000e+01,2.9480000e+01,2.9480000e+01,
                        1.4570000e+00,0.0000000e+00,0.0000000e+00,1.4570000e+00,
                        1.4570000e+00,1.4570000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        6.4000000e+01,0.0000000e+00,0.0000000e+00,6.4000000e+01,
                        6.4000000e+01,6.4000000e+01,1.1764706e-01,2.9411765e-01,
                        5.8823529e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,3.6000000e+01,0.0000000e+00,
                        0.0000000e+00,3.6000000e+01,3.6000000e+01,3.6000000e+01,
                        1.0100000e+02,0.0000000e+00,0.0000000e+00,1.0100000e+02,
                        1.0100000e+02,1.0100000e+02,8.3798000e+01,0.0000000e+00,
                        0.0000000e+00,8.3798000e+01,8.3798000e+01,8.3798000e+01,
                        1.1579000e+02,0.0000000e+00,0.0000000e+00,1.1579000e+02,
                        1.1579000e+02,1.1579000e+02,1.8000000e+01,0.0000000e+00,
                        0.0000000e+00,1.8000000e+01,1.8000000e+01,1.8000000e+01,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.1600000e+02,0.0000000e+00,
                        0.0000000e+00,1.1600000e+02,1.1600000e+02,1.1600000e+02,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.8000000e+01,0.0000000e+00,
                        0.0000000e+00,1.8000000e+01,1.8000000e+01,1.8000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.6060000e+01,0.0000000e+00,
                        0.0000000e+00,3.6060000e+01,3.6060000e+01,3.6060000e+01,
                        7.5350000e+00,0.0000000e+00,0.0000000e+00,7.5350000e+00,
                        7.5350000e+00,7.5350000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,1.1111111e-01,3.3333333e-01,
                        5.5555556e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,3.7000000e+01,0.0000000e+00,
                        0.0000000e+00,3.7000000e+01,3.7000000e+01,3.7000000e+01,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,8.5467800e+01,0.0000000e+00,
                        0.0000000e+00,8.5467800e+01,8.5467800e+01,8.5467800e+01,
                        3.1246000e+02,0.0000000e+00,0.0000000e+00,3.1246000e+02,
                        3.1246000e+02,3.1246000e+02,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,2.2000000e+02,0.0000000e+00,
                        0.0000000e+00,2.2000000e+02,2.2000000e+02,2.2000000e+02,
                        8.2000000e-01,0.0000000e+00,0.0000000e+00,8.2000000e-01,
                        8.2000000e-01,8.2000000e-01,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,9.0722500e+01,0.0000000e+00,
                        0.0000000e+00,9.0722500e+01,9.0722500e+01,9.0722500e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2900000e+02,0.0000000e+00,0.0000000e+00,2.2900000e+02,
                        2.2900000e+02,2.2900000e+02,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,3.8000000e+01,0.0000000e+00,
                        0.0000000e+00,3.8000000e+01,3.8000000e+01,3.8000000e+01,
                        8.0000000e+00,0.0000000e+00,0.0000000e+00,8.0000000e+00,
                        8.0000000e+00,8.0000000e+00,8.7620000e+01,0.0000000e+00,
                        0.0000000e+00,8.7620000e+01,8.7620000e+01,8.7620000e+01,
                        1.0500000e+03,0.0000000e+00,0.0000000e+00,1.0500000e+03,
                        1.0500000e+03,1.0500000e+03,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.9500000e+02,0.0000000e+00,
                        0.0000000e+00,1.9500000e+02,1.9500000e+02,1.9500000e+02,
                        9.5000000e-01,0.0000000e+00,0.0000000e+00,9.5000000e-01,
                        9.5000000e-01,9.5000000e-01,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.4230000e+01,0.0000000e+00,
                        0.0000000e+00,5.4230000e+01,5.4230000e+01,5.4230000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,3.9000000e+01,0.0000000e+00,
                        0.0000000e+00,3.9000000e+01,3.9000000e+01,3.9000000e+01,
                        1.2000000e+01,0.0000000e+00,0.0000000e+00,1.2000000e+01,
                        1.2000000e+01,1.2000000e+01,8.8905850e+01,0.0000000e+00,
                        0.0000000e+00,8.8905850e+01,8.8905850e+01,8.8905850e+01,
                        1.7990000e+03,0.0000000e+00,0.0000000e+00,1.7990000e+03,
                        1.7990000e+03,1.7990000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.9000000e+02,0.0000000e+00,
                        0.0000000e+00,1.9000000e+02,1.9000000e+02,1.9000000e+02,
                        1.2200000e+00,0.0000000e+00,0.0000000e+00,1.2200000e+00,
                        1.2200000e+00,1.2200000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,3.2365000e+01,0.0000000e+00,
                        0.0000000e+00,3.2365000e+01,3.2365000e+01,3.2365000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,6.6666667e-01,0.0000000e+00,
                        3.3333333e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,4.0000000e+01,0.0000000e+00,
                        0.0000000e+00,4.0000000e+01,4.0000000e+01,4.0000000e+01,
                        4.4000000e+01,0.0000000e+00,0.0000000e+00,4.4000000e+01,
                        4.4000000e+01,4.4000000e+01,9.1224000e+01,0.0000000e+00,
                        0.0000000e+00,9.1224000e+01,9.1224000e+01,9.1224000e+01,
                        2.1280000e+03,0.0000000e+00,0.0000000e+00,2.1280000e+03,
                        2.1280000e+03,2.1280000e+03,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,4.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.7500000e+02,0.0000000e+00,
                        0.0000000e+00,1.7500000e+02,1.7500000e+02,1.7500000e+02,
                        1.3300000e+00,0.0000000e+00,0.0000000e+00,1.3300000e+00,
                        1.3300000e+00,1.3300000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,4.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        8.0000000e+00,0.0000000e+00,0.0000000e+00,8.0000000e+00,
                        8.0000000e+00,8.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        8.0000000e+00,0.0000000e+00,0.0000000e+00,8.0000000e+00,
                        8.0000000e+00,8.0000000e+00,2.3195000e+01,0.0000000e+00,
                        0.0000000e+00,2.3195000e+01,2.3195000e+01,2.3195000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,5.0000000e-01,0.0000000e+00,
                        5.0000000e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,4.1000000e+01,0.0000000e+00,
                        0.0000000e+00,4.1000000e+01,4.1000000e+01,4.1000000e+01,
                        4.7000000e+01,0.0000000e+00,0.0000000e+00,4.7000000e+01,
                        4.7000000e+01,4.7000000e+01,9.2906380e+01,0.0000000e+00,
                        0.0000000e+00,9.2906380e+01,9.2906380e+01,9.2906380e+01,
                        2.7500000e+03,0.0000000e+00,0.0000000e+00,2.7500000e+03,
                        2.7500000e+03,2.7500000e+03,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.6400000e+02,0.0000000e+00,
                        0.0000000e+00,1.6400000e+02,1.6400000e+02,1.6400000e+02,
                        1.6000000e+00,0.0000000e+00,0.0000000e+00,1.6000000e+00,
                        1.6000000e+00,1.6000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,4.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,1.8180000e+01,0.0000000e+00,
                        0.0000000e+00,1.8180000e+01,1.8180000e+01,1.8180000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2900000e+02,0.0000000e+00,0.0000000e+00,2.2900000e+02,
                        2.2900000e+02,2.2900000e+02,2.0000000e-01,0.0000000e+00,
                        8.0000000e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,4.2000000e+01,0.0000000e+00,
                        0.0000000e+00,4.2000000e+01,4.2000000e+01,4.2000000e+01,
                        5.0000000e+01,0.0000000e+00,0.0000000e+00,5.0000000e+01,
                        5.0000000e+01,5.0000000e+01,9.5960000e+01,0.0000000e+00,
                        0.0000000e+00,9.5960000e+01,9.5960000e+01,9.5960000e+01,
                        2.8960000e+03,0.0000000e+00,0.0000000e+00,2.8960000e+03,
                        2.8960000e+03,2.8960000e+03,6.0000000e+00,0.0000000e+00,
                        0.0000000e+00,6.0000000e+00,6.0000000e+00,6.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.5400000e+02,0.0000000e+00,
                        0.0000000e+00,1.5400000e+02,1.5400000e+02,1.5400000e+02,
                        2.1600000e+00,0.0000000e+00,0.0000000e+00,2.1600000e+00,
                        2.1600000e+00,2.1600000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,6.0000000e+00,0.0000000e+00,
                        0.0000000e+00,6.0000000e+00,6.0000000e+00,6.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.5690000e+01,0.0000000e+00,
                        0.0000000e+00,1.5690000e+01,1.5690000e+01,1.5690000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2900000e+02,0.0000000e+00,0.0000000e+00,2.2900000e+02,
                        2.2900000e+02,2.2900000e+02,1.6666667e-01,0.0000000e+00,
                        8.3333333e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,4.3000000e+01,0.0000000e+00,
                        0.0000000e+00,4.3000000e+01,4.3000000e+01,4.3000000e+01,
                        5.3000000e+01,0.0000000e+00,0.0000000e+00,5.3000000e+01,
                        5.3000000e+01,5.3000000e+01,9.8000000e+01,0.0000000e+00,
                        0.0000000e+00,9.8000000e+01,9.8000000e+01,9.8000000e+01,
                        2.4300000e+03,0.0000000e+00,0.0000000e+00,2.4300000e+03,
                        2.4300000e+03,2.4300000e+03,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,7.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.4700000e+02,0.0000000e+00,
                        0.0000000e+00,1.4700000e+02,1.4700000e+02,1.4700000e+02,
                        1.9000000e+00,0.0000000e+00,0.0000000e+00,1.9000000e+00,
                        1.9000000e+00,1.9000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,7.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.4285000e+01,0.0000000e+00,
                        0.0000000e+00,1.4285000e+01,1.4285000e+01,1.4285000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,2.8571429e-01,0.0000000e+00,
                        7.1428571e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,4.4000000e+01,0.0000000e+00,
                        0.0000000e+00,4.4000000e+01,4.4000000e+01,4.4000000e+01,
                        5.6000000e+01,0.0000000e+00,0.0000000e+00,5.6000000e+01,
                        5.6000000e+01,5.6000000e+01,1.0107000e+02,0.0000000e+00,
                        0.0000000e+00,1.0107000e+02,1.0107000e+02,1.0107000e+02,
                        2.6070000e+03,0.0000000e+00,0.0000000e+00,2.6070000e+03,
                        2.6070000e+03,2.6070000e+03,8.0000000e+00,0.0000000e+00,
                        0.0000000e+00,8.0000000e+00,8.0000000e+00,8.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.4600000e+02,0.0000000e+00,
                        0.0000000e+00,1.4600000e+02,1.4600000e+02,1.4600000e+02,
                        2.2000000e+00,0.0000000e+00,0.0000000e+00,2.2000000e+00,
                        2.2000000e+00,2.2000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,7.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,8.0000000e+00,0.0000000e+00,
                        0.0000000e+00,8.0000000e+00,8.0000000e+00,8.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.3510000e+01,0.0000000e+00,
                        0.0000000e+00,1.3510000e+01,1.3510000e+01,1.3510000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,1.2500000e-01,0.0000000e+00,
                        8.7500000e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,4.5000000e+01,0.0000000e+00,
                        0.0000000e+00,4.5000000e+01,4.5000000e+01,4.5000000e+01,
                        5.9000000e+01,0.0000000e+00,0.0000000e+00,5.9000000e+01,
                        5.9000000e+01,5.9000000e+01,1.0290550e+02,0.0000000e+00,
                        0.0000000e+00,1.0290550e+02,1.0290550e+02,1.0290550e+02,
                        2.2370000e+03,0.0000000e+00,0.0000000e+00,2.2370000e+03,
                        2.2370000e+03,2.2370000e+03,9.0000000e+00,0.0000000e+00,
                        0.0000000e+00,9.0000000e+00,9.0000000e+00,9.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.4200000e+02,0.0000000e+00,
                        0.0000000e+00,1.4200000e+02,1.4200000e+02,1.4200000e+02,
                        2.2800000e+00,0.0000000e+00,0.0000000e+00,2.2800000e+00,
                        2.2800000e+00,2.2800000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,8.0000000e+00,0.0000000e+00,
                        0.0000000e+00,8.0000000e+00,8.0000000e+00,8.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,9.0000000e+00,0.0000000e+00,
                        0.0000000e+00,9.0000000e+00,9.0000000e+00,9.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,1.3640000e+01,0.0000000e+00,
                        0.0000000e+00,1.3640000e+01,1.3640000e+01,1.3640000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,1.1111111e-01,0.0000000e+00,
                        8.8888889e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,4.6000000e+01,0.0000000e+00,
                        0.0000000e+00,4.6000000e+01,4.6000000e+01,4.6000000e+01,
                        6.2000000e+01,0.0000000e+00,0.0000000e+00,6.2000000e+01,
                        6.2000000e+01,6.2000000e+01,1.0642000e+02,0.0000000e+00,
                        0.0000000e+00,1.0642000e+02,1.0642000e+02,1.0642000e+02,
                        1.8280500e+03,0.0000000e+00,0.0000000e+00,1.8280500e+03,
                        1.8280500e+03,1.8280500e+03,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.3900000e+02,0.0000000e+00,
                        0.0000000e+00,1.3900000e+02,1.3900000e+02,1.3900000e+02,
                        2.2000000e+00,0.0000000e+00,0.0000000e+00,2.2000000e+00,
                        2.2000000e+00,2.2000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.4410000e+01,0.0000000e+00,
                        0.0000000e+00,1.4410000e+01,1.4410000e+01,1.4410000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,0.0000000e+00,0.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,4.7000000e+01,0.0000000e+00,
                        0.0000000e+00,4.7000000e+01,4.7000000e+01,4.7000000e+01,
                        6.5000000e+01,0.0000000e+00,0.0000000e+00,6.5000000e+01,
                        6.5000000e+01,6.5000000e+01,1.0786820e+02,0.0000000e+00,
                        0.0000000e+00,1.0786820e+02,1.0786820e+02,1.0786820e+02,
                        1.2349300e+03,0.0000000e+00,0.0000000e+00,1.2349300e+03,
                        1.2349300e+03,1.2349300e+03,1.1000000e+01,0.0000000e+00,
                        0.0000000e+00,1.1000000e+01,1.1000000e+01,1.1000000e+01,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.4500000e+02,0.0000000e+00,
                        0.0000000e+00,1.4500000e+02,1.4500000e+02,1.4500000e+02,
                        1.9300000e+00,0.0000000e+00,0.0000000e+00,1.9300000e+00,
                        1.9300000e+00,1.9300000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.1000000e+01,0.0000000e+00,
                        0.0000000e+00,1.1000000e+01,1.1000000e+01,1.1000000e+01,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.6330000e+01,0.0000000e+00,
                        0.0000000e+00,1.6330000e+01,1.6330000e+01,1.6330000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,9.0909091e-02,0.0000000e+00,
                        9.0909091e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,4.8000000e+01,0.0000000e+00,
                        0.0000000e+00,4.8000000e+01,4.8000000e+01,4.8000000e+01,
                        7.0000000e+01,0.0000000e+00,0.0000000e+00,7.0000000e+01,
                        7.0000000e+01,7.0000000e+01,1.1241100e+02,0.0000000e+00,
                        0.0000000e+00,1.1241100e+02,1.1241100e+02,1.1241100e+02,
                        5.9422000e+02,0.0000000e+00,0.0000000e+00,5.9422000e+02,
                        5.9422000e+02,5.9422000e+02,1.2000000e+01,0.0000000e+00,
                        0.0000000e+00,1.2000000e+01,1.2000000e+01,1.2000000e+01,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.4400000e+02,0.0000000e+00,
                        0.0000000e+00,1.4400000e+02,1.4400000e+02,1.4400000e+02,
                        1.6900000e+00,0.0000000e+00,0.0000000e+00,1.6900000e+00,
                        1.6900000e+00,1.6900000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.2000000e+01,0.0000000e+00,
                        0.0000000e+00,1.2000000e+01,1.2000000e+01,1.2000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.9495000e+01,0.0000000e+00,
                        0.0000000e+00,1.9495000e+01,1.9495000e+01,1.9495000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,1.6666667e-01,0.0000000e+00,
                        8.3333333e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,4.9000000e+01,0.0000000e+00,
                        0.0000000e+00,4.9000000e+01,4.9000000e+01,4.9000000e+01,
                        7.5000000e+01,0.0000000e+00,0.0000000e+00,7.5000000e+01,
                        7.5000000e+01,7.5000000e+01,1.1481800e+02,0.0000000e+00,
                        0.0000000e+00,1.1481800e+02,1.1481800e+02,1.1481800e+02,
                        4.2975000e+02,0.0000000e+00,0.0000000e+00,4.2975000e+02,
                        4.2975000e+02,4.2975000e+02,1.3000000e+01,0.0000000e+00,
                        0.0000000e+00,1.3000000e+01,1.3000000e+01,1.3000000e+01,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.4200000e+02,0.0000000e+00,
                        0.0000000e+00,1.4200000e+02,1.4200000e+02,1.4200000e+02,
                        1.7800000e+00,0.0000000e+00,0.0000000e+00,1.7800000e+00,
                        1.7800000e+00,1.7800000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.3000000e+01,0.0000000e+00,
                        0.0000000e+00,1.3000000e+01,1.3000000e+01,1.3000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,2.4260000e+01,0.0000000e+00,
                        0.0000000e+00,2.4260000e+01,2.4260000e+01,2.4260000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.3900000e+02,0.0000000e+00,0.0000000e+00,1.3900000e+02,
                        1.3900000e+02,1.3900000e+02,1.5384615e-01,7.6923077e-02,
                        7.6923077e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,5.0000000e+01,0.0000000e+00,
                        0.0000000e+00,5.0000000e+01,5.0000000e+01,5.0000000e+01,
                        8.0000000e+01,0.0000000e+00,0.0000000e+00,8.0000000e+01,
                        8.0000000e+01,8.0000000e+01,1.1871000e+02,0.0000000e+00,
                        0.0000000e+00,1.1871000e+02,1.1871000e+02,1.1871000e+02,
                        5.0508000e+02,0.0000000e+00,0.0000000e+00,5.0508000e+02,
                        5.0508000e+02,5.0508000e+02,1.4000000e+01,0.0000000e+00,
                        0.0000000e+00,1.4000000e+01,1.4000000e+01,1.4000000e+01,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.3900000e+02,0.0000000e+00,
                        0.0000000e+00,1.3900000e+02,1.3900000e+02,1.3900000e+02,
                        1.9600000e+00,0.0000000e+00,0.0000000e+00,1.9600000e+00,
                        1.9600000e+00,1.9600000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.4000000e+01,0.0000000e+00,
                        0.0000000e+00,1.4000000e+01,1.4000000e+01,1.4000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,4.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,3.3285000e+01,0.0000000e+00,
                        0.0000000e+00,3.3285000e+01,3.3285000e+01,3.3285000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.4100000e+02,0.0000000e+00,0.0000000e+00,1.4100000e+02,
                        1.4100000e+02,1.4100000e+02,1.4285714e-01,1.4285714e-01,
                        7.1428571e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,5.1000000e+01,0.0000000e+00,
                        0.0000000e+00,5.1000000e+01,5.1000000e+01,5.1000000e+01,
                        8.5000000e+01,0.0000000e+00,0.0000000e+00,8.5000000e+01,
                        8.5000000e+01,8.5000000e+01,1.2176000e+02,0.0000000e+00,
                        0.0000000e+00,1.2176000e+02,1.2176000e+02,1.2176000e+02,
                        9.0378000e+02,0.0000000e+00,0.0000000e+00,9.0378000e+02,
                        9.0378000e+02,9.0378000e+02,1.5000000e+01,0.0000000e+00,
                        0.0000000e+00,1.5000000e+01,1.5000000e+01,1.5000000e+01,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.3900000e+02,0.0000000e+00,
                        0.0000000e+00,1.3900000e+02,1.3900000e+02,1.3900000e+02,
                        2.0500000e+00,0.0000000e+00,0.0000000e+00,2.0500000e+00,
                        2.0500000e+00,2.0500000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.5000000e+01,0.0000000e+00,
                        0.0000000e+00,1.5000000e+01,1.5000000e+01,1.5000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,3.1560000e+01,0.0000000e+00,
                        0.0000000e+00,3.1560000e+01,3.1560000e+01,3.1560000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.6600000e+02,0.0000000e+00,0.0000000e+00,1.6600000e+02,
                        1.6600000e+02,1.6600000e+02,1.3333333e-01,2.0000000e-01,
                        6.6666667e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,5.2000000e+01,0.0000000e+00,
                        0.0000000e+00,5.2000000e+01,5.2000000e+01,5.2000000e+01,
                        9.0000000e+01,0.0000000e+00,0.0000000e+00,9.0000000e+01,
                        9.0000000e+01,9.0000000e+01,1.2760000e+02,0.0000000e+00,
                        0.0000000e+00,1.2760000e+02,1.2760000e+02,1.2760000e+02,
                        7.2266000e+02,0.0000000e+00,0.0000000e+00,7.2266000e+02,
                        7.2266000e+02,7.2266000e+02,1.6000000e+01,0.0000000e+00,
                        0.0000000e+00,1.6000000e+01,1.6000000e+01,1.6000000e+01,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.3800000e+02,0.0000000e+00,
                        0.0000000e+00,1.3800000e+02,1.3800000e+02,1.3800000e+02,
                        2.1000000e+00,0.0000000e+00,0.0000000e+00,2.1000000e+00,
                        2.1000000e+00,2.1000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.6000000e+01,0.0000000e+00,
                        0.0000000e+00,1.6000000e+01,1.6000000e+01,1.6000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,3.4763333e+01,0.0000000e+00,
                        0.0000000e+00,3.4763333e+01,3.4763333e+01,3.4763333e+01,
                        4.6400000e-01,0.0000000e+00,0.0000000e+00,4.6400000e-01,
                        4.6400000e-01,4.6400000e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.5200000e+02,0.0000000e+00,0.0000000e+00,1.5200000e+02,
                        1.5200000e+02,1.5200000e+02,1.2500000e-01,2.5000000e-01,
                        6.2500000e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,5.3000000e+01,0.0000000e+00,
                        0.0000000e+00,5.3000000e+01,5.3000000e+01,5.3000000e+01,
                        9.6000000e+01,0.0000000e+00,0.0000000e+00,9.6000000e+01,
                        9.6000000e+01,9.6000000e+01,1.2690447e+02,0.0000000e+00,
                        0.0000000e+00,1.2690447e+02,1.2690447e+02,1.2690447e+02,
                        3.8685000e+02,0.0000000e+00,0.0000000e+00,3.8685000e+02,
                        3.8685000e+02,3.8685000e+02,1.7000000e+01,0.0000000e+00,
                        0.0000000e+00,1.7000000e+01,1.7000000e+01,1.7000000e+01,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.3900000e+02,0.0000000e+00,
                        0.0000000e+00,1.3900000e+02,1.3900000e+02,1.3900000e+02,
                        2.6600000e+00,0.0000000e+00,0.0000000e+00,2.6600000e+00,
                        2.6600000e+00,2.6600000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.7000000e+01,0.0000000e+00,
                        0.0000000e+00,1.7000000e+01,1.7000000e+01,1.7000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,4.3015000e+01,0.0000000e+00,
                        0.0000000e+00,4.3015000e+01,4.3015000e+01,4.3015000e+01,
                        1.0620000e+00,0.0000000e+00,0.0000000e+00,1.0620000e+00,
                        1.0620000e+00,1.0620000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        6.4000000e+01,0.0000000e+00,0.0000000e+00,6.4000000e+01,
                        6.4000000e+01,6.4000000e+01,1.1764706e-01,2.9411765e-01,
                        5.8823529e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,5.4000000e+01,0.0000000e+00,
                        0.0000000e+00,5.4000000e+01,5.4000000e+01,5.4000000e+01,
                        1.0200000e+02,0.0000000e+00,0.0000000e+00,1.0200000e+02,
                        1.0200000e+02,1.0200000e+02,1.3129300e+02,0.0000000e+00,
                        0.0000000e+00,1.3129300e+02,1.3129300e+02,1.3129300e+02,
                        1.6130000e+02,0.0000000e+00,0.0000000e+00,1.6130000e+02,
                        1.6130000e+02,1.6130000e+02,1.8000000e+01,0.0000000e+00,
                        0.0000000e+00,1.8000000e+01,1.8000000e+01,1.8000000e+01,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.4000000e+02,0.0000000e+00,
                        0.0000000e+00,1.4000000e+02,1.4000000e+02,1.4000000e+02,
                        2.6000000e+00,0.0000000e+00,0.0000000e+00,2.6000000e+00,
                        2.6000000e+00,2.6000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.8000000e+01,0.0000000e+00,
                        0.0000000e+00,1.8000000e+01,1.8000000e+01,1.8000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.3650000e+01,0.0000000e+00,
                        0.0000000e+00,5.3650000e+01,5.3650000e+01,5.3650000e+01,
                        6.4560000e+00,0.0000000e+00,0.0000000e+00,6.4560000e+00,
                        6.4560000e+00,6.4560000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,1.1111111e-01,3.3333333e-01,
                        5.5555556e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,5.5000000e+01,0.0000000e+00,
                        0.0000000e+00,5.5000000e+01,5.5000000e+01,5.5000000e+01,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.3290545e+02,0.0000000e+00,
                        0.0000000e+00,1.3290545e+02,1.3290545e+02,1.3290545e+02,
                        3.0159000e+02,0.0000000e+00,0.0000000e+00,3.0159000e+02,
                        3.0159000e+02,3.0159000e+02,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,2.4400000e+02,0.0000000e+00,
                        0.0000000e+00,2.4400000e+02,2.4400000e+02,2.4400000e+02,
                        7.9000000e-01,0.0000000e+00,0.0000000e+00,7.9000000e-01,
                        7.9000000e-01,7.9000000e-01,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.1576500e+02,0.0000000e+00,
                        0.0000000e+00,1.1576500e+02,1.1576500e+02,1.1576500e+02,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2900000e+02,0.0000000e+00,0.0000000e+00,2.2900000e+02,
                        2.2900000e+02,2.2900000e+02,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,5.6000000e+01,0.0000000e+00,
                        0.0000000e+00,5.6000000e+01,5.6000000e+01,5.6000000e+01,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,1.3732700e+02,0.0000000e+00,
                        0.0000000e+00,1.3732700e+02,1.3732700e+02,1.3732700e+02,
                        1.0000000e+03,0.0000000e+00,0.0000000e+00,1.0000000e+03,
                        1.0000000e+03,1.0000000e+03,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,2.1500000e+02,0.0000000e+00,
                        0.0000000e+00,2.1500000e+02,2.1500000e+02,2.1500000e+02,
                        8.9000000e-01,0.0000000e+00,0.0000000e+00,8.9000000e-01,
                        8.9000000e-01,8.9000000e-01,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,6.3590000e+01,0.0000000e+00,
                        0.0000000e+00,6.3590000e+01,6.3590000e+01,6.3590000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2900000e+02,0.0000000e+00,0.0000000e+00,2.2900000e+02,
                        2.2900000e+02,2.2900000e+02,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,5.7000000e+01,0.0000000e+00,
                        0.0000000e+00,5.7000000e+01,5.7000000e+01,5.7000000e+01,
                        1.3000000e+01,0.0000000e+00,0.0000000e+00,1.3000000e+01,
                        1.3000000e+01,1.3000000e+01,1.3890547e+02,0.0000000e+00,
                        0.0000000e+00,1.3890547e+02,1.3890547e+02,1.3890547e+02,
                        1.1930000e+03,0.0000000e+00,0.0000000e+00,1.1930000e+03,
                        1.1930000e+03,1.1930000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,2.0700000e+02,0.0000000e+00,
                        0.0000000e+00,2.0700000e+02,2.0700000e+02,2.0700000e+02,
                        1.1000000e+00,0.0000000e+00,0.0000000e+00,1.1000000e+00,
                        1.1000000e+00,1.1000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,3.6897500e+01,0.0000000e+00,
                        0.0000000e+00,3.6897500e+01,3.6897500e+01,3.6897500e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,6.6666667e-01,0.0000000e+00,
                        3.3333333e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,5.8000000e+01,0.0000000e+00,
                        0.0000000e+00,5.8000000e+01,5.8000000e+01,5.8000000e+01,
                        1.5000000e+01,0.0000000e+00,0.0000000e+00,1.5000000e+01,
                        1.5000000e+01,1.5000000e+01,1.4011600e+02,0.0000000e+00,
                        0.0000000e+00,1.4011600e+02,1.4011600e+02,1.4011600e+02,
                        1.0710000e+03,0.0000000e+00,0.0000000e+00,1.0710000e+03,
                        1.0710000e+03,1.0710000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,2.0400000e+02,0.0000000e+00,
                        0.0000000e+00,2.0400000e+02,2.0400000e+02,2.0400000e+02,
                        1.1200000e+00,0.0000000e+00,0.0000000e+00,1.1200000e+00,
                        1.1200000e+00,1.1200000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,4.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,1.3000000e+01,0.0000000e+00,
                        0.0000000e+00,1.3000000e+01,1.3000000e+01,1.3000000e+01,
                        2.2000000e+01,0.0000000e+00,0.0000000e+00,2.2000000e+01,
                        2.2000000e+01,2.2000000e+01,3.7240000e+01,0.0000000e+00,
                        0.0000000e+00,3.7240000e+01,3.7240000e+01,3.7240000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,5.0000000e-01,0.0000000e+00,
                        2.5000000e-01,2.5000000e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,5.9000000e+01,0.0000000e+00,
                        0.0000000e+00,5.9000000e+01,5.9000000e+01,5.9000000e+01,
                        1.7000000e+01,0.0000000e+00,0.0000000e+00,1.7000000e+01,
                        1.7000000e+01,1.7000000e+01,1.4090765e+02,0.0000000e+00,
                        0.0000000e+00,1.4090765e+02,1.4090765e+02,1.4090765e+02,
                        1.2040000e+03,0.0000000e+00,0.0000000e+00,1.2040000e+03,
                        1.2040000e+03,1.2040000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,2.0300000e+02,0.0000000e+00,
                        0.0000000e+00,2.0300000e+02,2.0300000e+02,2.0300000e+02,
                        1.1300000e+00,0.0000000e+00,0.0000000e+00,1.1300000e+00,
                        1.1300000e+00,1.1300000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.1000000e+01,0.0000000e+00,
                        0.0000000e+00,1.1000000e+01,1.1000000e+01,1.1000000e+01,
                        1.1000000e+01,0.0000000e+00,0.0000000e+00,1.1000000e+01,
                        1.1000000e+01,1.1000000e+01,3.5675000e+01,0.0000000e+00,
                        0.0000000e+00,3.5675000e+01,3.5675000e+01,3.5675000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,4.0000000e-01,0.0000000e+00,
                        0.0000000e+00,6.0000000e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,6.0000000e+01,0.0000000e+00,
                        0.0000000e+00,6.0000000e+01,6.0000000e+01,6.0000000e+01,
                        1.9000000e+01,0.0000000e+00,0.0000000e+00,1.9000000e+01,
                        1.9000000e+01,1.9000000e+01,1.4424200e+02,0.0000000e+00,
                        0.0000000e+00,1.4424200e+02,1.4424200e+02,1.4424200e+02,
                        1.2940000e+03,0.0000000e+00,0.0000000e+00,1.2940000e+03,
                        1.2940000e+03,1.2940000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,2.0100000e+02,0.0000000e+00,
                        0.0000000e+00,2.0100000e+02,2.0100000e+02,2.0100000e+02,
                        1.1400000e+00,0.0000000e+00,0.0000000e+00,1.1400000e+00,
                        1.1400000e+00,1.1400000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,6.0000000e+00,0.0000000e+00,
                        0.0000000e+00,6.0000000e+00,6.0000000e+00,6.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        1.0000000e+01,0.0000000e+00,0.0000000e+00,1.0000000e+01,
                        1.0000000e+01,1.0000000e+01,3.4810000e+01,0.0000000e+00,
                        0.0000000e+00,3.4810000e+01,3.4810000e+01,3.4810000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,3.3333333e-01,0.0000000e+00,
                        0.0000000e+00,6.6666667e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,6.1000000e+01,0.0000000e+00,
                        0.0000000e+00,6.1000000e+01,6.1000000e+01,6.1000000e+01,
                        2.1000000e+01,0.0000000e+00,0.0000000e+00,2.1000000e+01,
                        2.1000000e+01,2.1000000e+01,1.4500000e+02,0.0000000e+00,
                        0.0000000e+00,1.4500000e+02,1.4500000e+02,1.4500000e+02,
                        1.3730000e+03,0.0000000e+00,0.0000000e+00,1.3730000e+03,
                        1.3730000e+03,1.3730000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.9900000e+02,0.0000000e+00,
                        0.0000000e+00,1.9900000e+02,1.9900000e+02,1.9900000e+02,
                        1.1550000e+00,0.0000000e+00,0.0000000e+00,1.1550000e+00,
                        1.1550000e+00,1.1550000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,7.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,9.0000000e+00,0.0000000e+00,
                        0.0000000e+00,9.0000000e+00,9.0000000e+00,9.0000000e+00,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,3.3842500e+01,0.0000000e+00,
                        0.0000000e+00,3.3842500e+01,3.3842500e+01,3.3842500e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,2.8571429e-01,0.0000000e+00,
                        0.0000000e+00,7.1428571e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,6.2000000e+01,0.0000000e+00,
                        0.0000000e+00,6.2000000e+01,6.2000000e+01,6.2000000e+01,
                        2.3000000e+01,0.0000000e+00,0.0000000e+00,2.3000000e+01,
                        2.3000000e+01,2.3000000e+01,1.5036000e+02,0.0000000e+00,
                        0.0000000e+00,1.5036000e+02,1.5036000e+02,1.5036000e+02,
                        1.3450000e+03,0.0000000e+00,0.0000000e+00,1.3450000e+03,
                        1.3450000e+03,1.3450000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.9800000e+02,0.0000000e+00,
                        0.0000000e+00,1.9800000e+02,1.9800000e+02,1.9800000e+02,
                        1.1700000e+00,0.0000000e+00,0.0000000e+00,1.1700000e+00,
                        1.1700000e+00,1.1700000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,8.0000000e+00,0.0000000e+00,
                        0.0000000e+00,8.0000000e+00,8.0000000e+00,8.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,8.0000000e+00,0.0000000e+00,
                        0.0000000e+00,8.0000000e+00,8.0000000e+00,8.0000000e+00,
                        8.0000000e+00,0.0000000e+00,0.0000000e+00,8.0000000e+00,
                        8.0000000e+00,8.0000000e+00,3.3230000e+01,0.0000000e+00,
                        0.0000000e+00,3.3230000e+01,3.3230000e+01,3.3230000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.6600000e+02,0.0000000e+00,0.0000000e+00,1.6600000e+02,
                        1.6600000e+02,1.6600000e+02,2.5000000e-01,0.0000000e+00,
                        0.0000000e+00,7.5000000e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,6.3000000e+01,0.0000000e+00,
                        0.0000000e+00,6.3000000e+01,6.3000000e+01,6.3000000e+01,
                        2.5000000e+01,0.0000000e+00,0.0000000e+00,2.5000000e+01,
                        2.5000000e+01,2.5000000e+01,1.5196400e+02,0.0000000e+00,
                        0.0000000e+00,1.5196400e+02,1.5196400e+02,1.5196400e+02,
                        1.0950000e+03,0.0000000e+00,0.0000000e+00,1.0950000e+03,
                        1.0950000e+03,1.0950000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.9800000e+02,0.0000000e+00,
                        0.0000000e+00,1.9800000e+02,1.9800000e+02,1.9800000e+02,
                        1.1850000e+00,0.0000000e+00,0.0000000e+00,1.1850000e+00,
                        1.1850000e+00,1.1850000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,9.0000000e+00,0.0000000e+00,
                        0.0000000e+00,9.0000000e+00,9.0000000e+00,9.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,7.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,3.6460000e+01,0.0000000e+00,
                        0.0000000e+00,3.6460000e+01,3.6460000e+01,3.6460000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2900000e+02,0.0000000e+00,0.0000000e+00,2.2900000e+02,
                        2.2900000e+02,2.2900000e+02,2.2222222e-01,0.0000000e+00,
                        0.0000000e+00,7.7777778e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,6.4000000e+01,0.0000000e+00,
                        0.0000000e+00,6.4000000e+01,6.4000000e+01,6.4000000e+01,
                        2.7000000e+01,0.0000000e+00,0.0000000e+00,2.7000000e+01,
                        2.7000000e+01,2.7000000e+01,1.5725000e+02,0.0000000e+00,
                        0.0000000e+00,1.5725000e+02,1.5725000e+02,1.5725000e+02,
                        1.5860000e+03,0.0000000e+00,0.0000000e+00,1.5860000e+03,
                        1.5860000e+03,1.5860000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.9600000e+02,0.0000000e+00,
                        0.0000000e+00,1.9600000e+02,1.9600000e+02,1.9600000e+02,
                        1.2000000e+00,0.0000000e+00,0.0000000e+00,1.2000000e+00,
                        1.2000000e+00,1.2000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,7.0000000e+00,
                        1.6000000e+01,0.0000000e+00,0.0000000e+00,1.6000000e+01,
                        1.6000000e+01,1.6000000e+01,3.2050000e+01,0.0000000e+00,
                        0.0000000e+00,3.2050000e+01,3.2050000e+01,3.2050000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,2.0000000e-01,0.0000000e+00,
                        1.0000000e-01,7.0000000e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,6.5000000e+01,0.0000000e+00,
                        0.0000000e+00,6.5000000e+01,6.5000000e+01,6.5000000e+01,
                        2.9000000e+01,0.0000000e+00,0.0000000e+00,2.9000000e+01,
                        2.9000000e+01,2.9000000e+01,1.5892535e+02,0.0000000e+00,
                        0.0000000e+00,1.5892535e+02,1.5892535e+02,1.5892535e+02,
                        1.6290000e+03,0.0000000e+00,0.0000000e+00,1.6290000e+03,
                        1.6290000e+03,1.6290000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.9400000e+02,0.0000000e+00,
                        0.0000000e+00,1.9400000e+02,1.9400000e+02,1.9400000e+02,
                        1.2100000e+00,0.0000000e+00,0.0000000e+00,1.2100000e+00,
                        1.2100000e+00,1.2100000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,1.1000000e+01,0.0000000e+00,
                        0.0000000e+00,1.1000000e+01,1.1000000e+01,1.1000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,3.1736667e+01,0.0000000e+00,
                        0.0000000e+00,3.1736667e+01,3.1736667e+01,3.1736667e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,1.8181818e-01,0.0000000e+00,
                        0.0000000e+00,8.1818182e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,6.6000000e+01,0.0000000e+00,
                        0.0000000e+00,6.6000000e+01,6.6000000e+01,6.6000000e+01,
                        3.1000000e+01,0.0000000e+00,0.0000000e+00,3.1000000e+01,
                        3.1000000e+01,3.1000000e+01,1.6250000e+02,0.0000000e+00,
                        0.0000000e+00,1.6250000e+02,1.6250000e+02,1.6250000e+02,
                        1.6850000e+03,0.0000000e+00,0.0000000e+00,1.6850000e+03,
                        1.6850000e+03,1.6850000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.9200000e+02,0.0000000e+00,
                        0.0000000e+00,1.9200000e+02,1.9200000e+02,1.9200000e+02,
                        1.2200000e+00,0.0000000e+00,0.0000000e+00,1.2200000e+00,
                        1.2200000e+00,1.2200000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.0000000e+01,0.0000000e+00,0.0000000e+00,1.0000000e+01,
                        1.0000000e+01,1.0000000e+01,1.2000000e+01,0.0000000e+00,
                        0.0000000e+00,1.2000000e+01,1.2000000e+01,1.2000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,4.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,3.1240000e+01,0.0000000e+00,
                        0.0000000e+00,3.1240000e+01,3.1240000e+01,3.1240000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,1.6666667e-01,0.0000000e+00,
                        0.0000000e+00,8.3333333e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,6.7000000e+01,0.0000000e+00,
                        0.0000000e+00,6.7000000e+01,6.7000000e+01,6.7000000e+01,
                        3.3000000e+01,0.0000000e+00,0.0000000e+00,3.3000000e+01,
                        3.3000000e+01,3.3000000e+01,1.6493032e+02,0.0000000e+00,
                        0.0000000e+00,1.6493032e+02,1.6493032e+02,1.6493032e+02,
                        1.7470000e+03,0.0000000e+00,0.0000000e+00,1.7470000e+03,
                        1.7470000e+03,1.7470000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.9200000e+02,0.0000000e+00,
                        0.0000000e+00,1.9200000e+02,1.9200000e+02,1.9200000e+02,
                        1.2300000e+00,0.0000000e+00,0.0000000e+00,1.2300000e+00,
                        1.2300000e+00,1.2300000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.1000000e+01,0.0000000e+00,0.0000000e+00,1.1000000e+01,
                        1.1000000e+01,1.1000000e+01,1.3000000e+01,0.0000000e+00,
                        0.0000000e+00,1.3000000e+01,1.3000000e+01,1.3000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,3.0733333e+01,0.0000000e+00,
                        0.0000000e+00,3.0733333e+01,3.0733333e+01,3.0733333e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,1.5384615e-01,0.0000000e+00,
                        0.0000000e+00,8.4615385e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,6.8000000e+01,0.0000000e+00,
                        0.0000000e+00,6.8000000e+01,6.8000000e+01,6.8000000e+01,
                        3.5000000e+01,0.0000000e+00,0.0000000e+00,3.5000000e+01,
                        3.5000000e+01,3.5000000e+01,1.6725900e+02,0.0000000e+00,
                        0.0000000e+00,1.6725900e+02,1.6725900e+02,1.6725900e+02,
                        1.7700000e+03,0.0000000e+00,0.0000000e+00,1.7700000e+03,
                        1.7700000e+03,1.7700000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.8900000e+02,0.0000000e+00,
                        0.0000000e+00,1.8900000e+02,1.8900000e+02,1.8900000e+02,
                        1.2400000e+00,0.0000000e+00,0.0000000e+00,1.2400000e+00,
                        1.2400000e+00,1.2400000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.2000000e+01,0.0000000e+00,0.0000000e+00,1.2000000e+01,
                        1.2000000e+01,1.2000000e+01,1.4000000e+01,0.0000000e+00,
                        0.0000000e+00,1.4000000e+01,1.4000000e+01,1.4000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,3.0585000e+01,0.0000000e+00,
                        0.0000000e+00,3.0585000e+01,3.0585000e+01,3.0585000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,1.4285714e-01,0.0000000e+00,
                        0.0000000e+00,8.5714286e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,6.9000000e+01,0.0000000e+00,
                        0.0000000e+00,6.9000000e+01,6.9000000e+01,6.9000000e+01,
                        3.7000000e+01,0.0000000e+00,0.0000000e+00,3.7000000e+01,
                        3.7000000e+01,3.7000000e+01,1.6893421e+02,0.0000000e+00,
                        0.0000000e+00,1.6893421e+02,1.6893421e+02,1.6893421e+02,
                        1.8180000e+03,0.0000000e+00,0.0000000e+00,1.8180000e+03,
                        1.8180000e+03,1.8180000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.9000000e+02,0.0000000e+00,
                        0.0000000e+00,1.9000000e+02,1.9000000e+02,1.9000000e+02,
                        1.2500000e+00,0.0000000e+00,0.0000000e+00,1.2500000e+00,
                        1.2500000e+00,1.2500000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.3000000e+01,0.0000000e+00,0.0000000e+00,1.3000000e+01,
                        1.3000000e+01,1.3000000e+01,1.5000000e+01,0.0000000e+00,
                        0.0000000e+00,1.5000000e+01,1.5000000e+01,1.5000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,2.9780000e+01,0.0000000e+00,
                        0.0000000e+00,2.9780000e+01,2.9780000e+01,2.9780000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,1.3333333e-01,0.0000000e+00,
                        0.0000000e+00,8.6666667e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,7.0000000e+01,0.0000000e+00,
                        0.0000000e+00,7.0000000e+01,7.0000000e+01,7.0000000e+01,
                        3.9000000e+01,0.0000000e+00,0.0000000e+00,3.9000000e+01,
                        3.9000000e+01,3.9000000e+01,1.7305400e+02,0.0000000e+00,
                        0.0000000e+00,1.7305400e+02,1.7305400e+02,1.7305400e+02,
                        1.0920000e+03,0.0000000e+00,0.0000000e+00,1.0920000e+03,
                        1.0920000e+03,1.0920000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.8700000e+02,0.0000000e+00,
                        0.0000000e+00,1.8700000e+02,1.8700000e+02,1.8700000e+02,
                        1.2600000e+00,0.0000000e+00,0.0000000e+00,1.2600000e+00,
                        1.2600000e+00,1.2600000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,1.6000000e+01,0.0000000e+00,
                        0.0000000e+00,1.6000000e+01,1.6000000e+01,1.6000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.4120000e+01,0.0000000e+00,
                        0.0000000e+00,3.4120000e+01,3.4120000e+01,3.4120000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,1.2500000e-01,0.0000000e+00,
                        0.0000000e+00,8.7500000e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,7.1000000e+01,0.0000000e+00,
                        0.0000000e+00,7.1000000e+01,7.1000000e+01,7.1000000e+01,
                        4.1000000e+01,0.0000000e+00,0.0000000e+00,4.1000000e+01,
                        4.1000000e+01,4.1000000e+01,1.7496680e+02,0.0000000e+00,
                        0.0000000e+00,1.7496680e+02,1.7496680e+02,1.7496680e+02,
                        1.9360000e+03,0.0000000e+00,0.0000000e+00,1.9360000e+03,
                        1.9360000e+03,1.9360000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.8700000e+02,0.0000000e+00,
                        0.0000000e+00,1.8700000e+02,1.8700000e+02,1.8700000e+02,
                        1.2700000e+00,0.0000000e+00,0.0000000e+00,1.2700000e+00,
                        1.2700000e+00,1.2700000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,1.7000000e+01,0.0000000e+00,
                        0.0000000e+00,1.7000000e+01,1.7000000e+01,1.7000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,2.8865000e+01,0.0000000e+00,
                        0.0000000e+00,2.8865000e+01,2.8865000e+01,2.8865000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.2471000e-03,0.0000000e+00,
                        0.0000000e+00,2.2471000e-03,2.2471000e-03,2.2471000e-03,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,1.1764706e-01,0.0000000e+00,
                        5.8823529e-02,8.2352941e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,7.2000000e+01,0.0000000e+00,
                        0.0000000e+00,7.2000000e+01,7.2000000e+01,7.2000000e+01,
                        4.5000000e+01,0.0000000e+00,0.0000000e+00,4.5000000e+01,
                        4.5000000e+01,4.5000000e+01,1.7849000e+02,0.0000000e+00,
                        0.0000000e+00,1.7849000e+02,1.7849000e+02,1.7849000e+02,
                        2.5060000e+03,0.0000000e+00,0.0000000e+00,2.5060000e+03,
                        2.5060000e+03,2.5060000e+03,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,4.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.7500000e+02,0.0000000e+00,
                        0.0000000e+00,1.7500000e+02,1.7500000e+02,1.7500000e+02,
                        1.3000000e+00,0.0000000e+00,0.0000000e+00,1.3000000e+00,
                        1.3000000e+00,1.3000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,1.8000000e+01,0.0000000e+00,
                        0.0000000e+00,1.8000000e+01,1.8000000e+01,1.8000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        8.0000000e+00,0.0000000e+00,0.0000000e+00,8.0000000e+00,
                        8.0000000e+00,8.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        8.0000000e+00,0.0000000e+00,0.0000000e+00,8.0000000e+00,
                        8.0000000e+00,8.0000000e+00,2.2200000e+01,0.0000000e+00,
                        0.0000000e+00,2.2200000e+01,2.2200000e+01,2.2200000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,1.1111111e-01,0.0000000e+00,
                        1.1111111e-01,7.7777778e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,7.3000000e+01,0.0000000e+00,
                        0.0000000e+00,7.3000000e+01,7.3000000e+01,7.3000000e+01,
                        4.8000000e+01,0.0000000e+00,0.0000000e+00,4.8000000e+01,
                        4.8000000e+01,4.8000000e+01,1.8094788e+02,0.0000000e+00,
                        0.0000000e+00,1.8094788e+02,1.8094788e+02,1.8094788e+02,
                        3.2900000e+03,0.0000000e+00,0.0000000e+00,3.2900000e+03,
                        3.2900000e+03,3.2900000e+03,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.7000000e+02,0.0000000e+00,
                        0.0000000e+00,1.7000000e+02,1.7000000e+02,1.7000000e+02,
                        1.5000000e+00,0.0000000e+00,0.0000000e+00,1.5000000e+00,
                        1.5000000e+00,1.5000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,1.9000000e+01,0.0000000e+00,
                        0.0000000e+00,1.9000000e+01,1.9000000e+01,1.9000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,1.8120000e+01,0.0000000e+00,
                        0.0000000e+00,1.8120000e+01,1.8120000e+01,1.8120000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2900000e+02,0.0000000e+00,0.0000000e+00,2.2900000e+02,
                        2.2900000e+02,2.2900000e+02,1.0526316e-01,0.0000000e+00,
                        1.5789474e-01,7.3684211e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,7.4000000e+01,0.0000000e+00,
                        0.0000000e+00,7.4000000e+01,7.4000000e+01,7.4000000e+01,
                        5.1000000e+01,0.0000000e+00,0.0000000e+00,5.1000000e+01,
                        5.1000000e+01,5.1000000e+01,1.8384000e+02,0.0000000e+00,
                        0.0000000e+00,1.8384000e+02,1.8384000e+02,1.8384000e+02,
                        3.6950000e+03,0.0000000e+00,0.0000000e+00,3.6950000e+03,
                        3.6950000e+03,3.6950000e+03,6.0000000e+00,0.0000000e+00,
                        0.0000000e+00,6.0000000e+00,6.0000000e+00,6.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.6200000e+02,0.0000000e+00,
                        0.0000000e+00,1.6200000e+02,1.6200000e+02,1.6200000e+02,
                        2.3600000e+00,0.0000000e+00,0.0000000e+00,2.3600000e+00,
                        2.3600000e+00,2.3600000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,4.0000000e+00,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,2.0000000e+01,0.0000000e+00,
                        0.0000000e+00,2.0000000e+01,2.0000000e+01,2.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.6050000e+01,0.0000000e+00,
                        0.0000000e+00,1.6050000e+01,1.6050000e+01,1.6050000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2900000e+02,0.0000000e+00,0.0000000e+00,2.2900000e+02,
                        2.2900000e+02,2.2900000e+02,1.0000000e-01,0.0000000e+00,
                        2.0000000e-01,7.0000000e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,7.5000000e+01,0.0000000e+00,
                        0.0000000e+00,7.5000000e+01,7.5000000e+01,7.5000000e+01,
                        5.4000000e+01,0.0000000e+00,0.0000000e+00,5.4000000e+01,
                        5.4000000e+01,5.4000000e+01,1.8620700e+02,0.0000000e+00,
                        0.0000000e+00,1.8620700e+02,1.8620700e+02,1.8620700e+02,
                        3.4590000e+03,0.0000000e+00,0.0000000e+00,3.4590000e+03,
                        3.4590000e+03,3.4590000e+03,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,7.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.5100000e+02,0.0000000e+00,
                        0.0000000e+00,1.5100000e+02,1.5100000e+02,1.5100000e+02,
                        1.9000000e+00,0.0000000e+00,0.0000000e+00,1.9000000e+00,
                        1.9000000e+00,1.9000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,2.1000000e+01,0.0000000e+00,
                        0.0000000e+00,2.1000000e+01,2.1000000e+01,2.1000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.4655000e+01,0.0000000e+00,
                        0.0000000e+00,1.4655000e+01,1.4655000e+01,1.4655000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,9.5238095e-02,0.0000000e+00,
                        2.3809524e-01,6.6666667e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,7.6000000e+01,0.0000000e+00,
                        0.0000000e+00,7.6000000e+01,7.6000000e+01,7.6000000e+01,
                        5.7000000e+01,0.0000000e+00,0.0000000e+00,5.7000000e+01,
                        5.7000000e+01,5.7000000e+01,1.9023000e+02,0.0000000e+00,
                        0.0000000e+00,1.9023000e+02,1.9023000e+02,1.9023000e+02,
                        3.3060000e+03,0.0000000e+00,0.0000000e+00,3.3060000e+03,
                        3.3060000e+03,3.3060000e+03,8.0000000e+00,0.0000000e+00,
                        0.0000000e+00,8.0000000e+00,8.0000000e+00,8.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.4400000e+02,0.0000000e+00,
                        0.0000000e+00,1.4400000e+02,1.4400000e+02,1.4400000e+02,
                        2.2000000e+00,0.0000000e+00,0.0000000e+00,2.2000000e+00,
                        2.2000000e+00,2.2000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,6.0000000e+00,0.0000000e+00,
                        0.0000000e+00,6.0000000e+00,6.0000000e+00,6.0000000e+00,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,2.2000000e+01,0.0000000e+00,
                        0.0000000e+00,2.2000000e+01,2.2000000e+01,2.2000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.4090000e+01,0.0000000e+00,
                        0.0000000e+00,1.4090000e+01,1.4090000e+01,1.4090000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,9.0909091e-02,0.0000000e+00,
                        2.7272727e-01,6.3636364e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,7.7000000e+01,0.0000000e+00,
                        0.0000000e+00,7.7000000e+01,7.7000000e+01,7.7000000e+01,
                        6.0000000e+01,0.0000000e+00,0.0000000e+00,6.0000000e+01,
                        6.0000000e+01,6.0000000e+01,1.9221700e+02,0.0000000e+00,
                        0.0000000e+00,1.9221700e+02,1.9221700e+02,1.9221700e+02,
                        2.7390000e+03,0.0000000e+00,0.0000000e+00,2.7390000e+03,
                        2.7390000e+03,2.7390000e+03,9.0000000e+00,0.0000000e+00,
                        0.0000000e+00,9.0000000e+00,9.0000000e+00,9.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.4100000e+02,0.0000000e+00,
                        0.0000000e+00,1.4100000e+02,1.4100000e+02,1.4100000e+02,
                        2.2000000e+00,0.0000000e+00,0.0000000e+00,2.2000000e+00,
                        2.2000000e+00,2.2000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,7.0000000e+00,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,2.3000000e+01,0.0000000e+00,
                        0.0000000e+00,2.3000000e+01,2.3000000e+01,2.3000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,1.4210000e+01,0.0000000e+00,
                        0.0000000e+00,1.4210000e+01,1.4210000e+01,1.4210000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,8.6956522e-02,0.0000000e+00,
                        3.0434783e-01,6.0869565e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,7.8000000e+01,0.0000000e+00,
                        0.0000000e+00,7.8000000e+01,7.8000000e+01,7.8000000e+01,
                        6.3000000e+01,0.0000000e+00,0.0000000e+00,6.3000000e+01,
                        6.3000000e+01,6.3000000e+01,1.9508400e+02,0.0000000e+00,
                        0.0000000e+00,1.9508400e+02,1.9508400e+02,1.9508400e+02,
                        2.0414000e+03,0.0000000e+00,0.0000000e+00,2.0414000e+03,
                        2.0414000e+03,2.0414000e+03,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.3600000e+02,0.0000000e+00,
                        0.0000000e+00,1.3600000e+02,1.3600000e+02,1.3600000e+02,
                        2.2800000e+00,0.0000000e+00,0.0000000e+00,2.2800000e+00,
                        2.2800000e+00,2.2800000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,9.0000000e+00,0.0000000e+00,
                        0.0000000e+00,9.0000000e+00,9.0000000e+00,9.0000000e+00,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,2.4000000e+01,0.0000000e+00,
                        0.0000000e+00,2.4000000e+01,2.4000000e+01,2.4000000e+01,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,1.5020000e+01,0.0000000e+00,
                        0.0000000e+00,1.5020000e+01,1.5020000e+01,1.5020000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,4.1666667e-02,0.0000000e+00,
                        3.7500000e-01,5.8333333e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,7.9000000e+01,0.0000000e+00,
                        0.0000000e+00,7.9000000e+01,7.9000000e+01,7.9000000e+01,
                        6.6000000e+01,0.0000000e+00,0.0000000e+00,6.6000000e+01,
                        6.6000000e+01,6.6000000e+01,1.9696657e+02,0.0000000e+00,
                        0.0000000e+00,1.9696657e+02,1.9696657e+02,1.9696657e+02,
                        1.3373300e+03,0.0000000e+00,0.0000000e+00,1.3373300e+03,
                        1.3373300e+03,1.3373300e+03,1.1000000e+01,0.0000000e+00,
                        0.0000000e+00,1.1000000e+01,1.1000000e+01,1.1000000e+01,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.3600000e+02,0.0000000e+00,
                        0.0000000e+00,1.3600000e+02,1.3600000e+02,1.3600000e+02,
                        2.5400000e+00,0.0000000e+00,0.0000000e+00,2.5400000e+00,
                        2.5400000e+00,2.5400000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,2.5000000e+01,0.0000000e+00,
                        0.0000000e+00,2.5000000e+01,2.5000000e+01,2.5000000e+01,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.6700000e+01,0.0000000e+00,
                        0.0000000e+00,1.6700000e+01,1.6700000e+01,1.6700000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,4.0000000e-02,0.0000000e+00,
                        4.0000000e-01,5.6000000e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,8.0000000e+01,0.0000000e+00,
                        0.0000000e+00,8.0000000e+01,8.0000000e+01,8.0000000e+01,
                        7.1000000e+01,0.0000000e+00,0.0000000e+00,7.1000000e+01,
                        7.1000000e+01,7.1000000e+01,2.0059000e+02,0.0000000e+00,
                        0.0000000e+00,2.0059000e+02,2.0059000e+02,2.0059000e+02,
                        2.3432000e+02,0.0000000e+00,0.0000000e+00,2.3432000e+02,
                        2.3432000e+02,2.3432000e+02,1.2000000e+01,0.0000000e+00,
                        0.0000000e+00,1.2000000e+01,1.2000000e+01,1.2000000e+01,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.3200000e+02,0.0000000e+00,
                        0.0000000e+00,1.3200000e+02,1.3200000e+02,1.3200000e+02,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,2.6000000e+01,0.0000000e+00,
                        0.0000000e+00,2.6000000e+01,2.6000000e+01,2.6000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.5237586e+01,0.0000000e+00,
                        0.0000000e+00,2.5237586e+01,2.5237586e+01,2.5237586e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.6600000e+02,0.0000000e+00,0.0000000e+00,1.6600000e+02,
                        1.6600000e+02,1.6600000e+02,7.6923077e-02,0.0000000e+00,
                        3.8461538e-01,5.3846154e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,8.1000000e+01,0.0000000e+00,
                        0.0000000e+00,8.1000000e+01,8.1000000e+01,8.1000000e+01,
                        7.6000000e+01,0.0000000e+00,0.0000000e+00,7.6000000e+01,
                        7.6000000e+01,7.6000000e+01,2.0438330e+02,0.0000000e+00,
                        0.0000000e+00,2.0438330e+02,2.0438330e+02,2.0438330e+02,
                        5.7700000e+02,0.0000000e+00,0.0000000e+00,5.7700000e+02,
                        5.7700000e+02,5.7700000e+02,1.3000000e+01,0.0000000e+00,
                        0.0000000e+00,1.3000000e+01,1.3000000e+01,1.3000000e+01,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.4500000e+02,0.0000000e+00,
                        0.0000000e+00,1.4500000e+02,1.4500000e+02,1.4500000e+02,
                        1.6200000e+00,0.0000000e+00,0.0000000e+00,1.6200000e+00,
                        1.6200000e+00,1.6200000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,2.7000000e+01,0.0000000e+00,
                        0.0000000e+00,2.7000000e+01,2.7000000e+01,2.7000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,2.6910000e+01,0.0000000e+00,
                        0.0000000e+00,2.6910000e+01,2.6910000e+01,2.6910000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,7.4074074e-02,3.7037037e-02,
                        3.7037037e-01,5.1851852e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,8.2000000e+01,0.0000000e+00,
                        0.0000000e+00,8.2000000e+01,8.2000000e+01,8.2000000e+01,
                        8.1000000e+01,0.0000000e+00,0.0000000e+00,8.1000000e+01,
                        8.1000000e+01,8.1000000e+01,2.0720000e+02,0.0000000e+00,
                        0.0000000e+00,2.0720000e+02,2.0720000e+02,2.0720000e+02,
                        6.0061000e+02,0.0000000e+00,0.0000000e+00,6.0061000e+02,
                        6.0061000e+02,6.0061000e+02,1.4000000e+01,0.0000000e+00,
                        0.0000000e+00,1.4000000e+01,1.4000000e+01,1.4000000e+01,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.4600000e+02,0.0000000e+00,
                        0.0000000e+00,1.4600000e+02,1.4600000e+02,1.4600000e+02,
                        2.3300000e+00,0.0000000e+00,0.0000000e+00,2.3300000e+00,
                        2.3300000e+00,2.3300000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,2.8000000e+01,0.0000000e+00,
                        0.0000000e+00,2.8000000e+01,2.8000000e+01,2.8000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,4.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,2.8110000e+01,0.0000000e+00,
                        0.0000000e+00,2.8110000e+01,2.8110000e+01,2.8110000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,7.1428571e-02,7.1428571e-02,
                        3.5714286e-01,5.0000000e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,8.3000000e+01,0.0000000e+00,
                        0.0000000e+00,8.3000000e+01,8.3000000e+01,8.3000000e+01,
                        8.6000000e+01,0.0000000e+00,0.0000000e+00,8.6000000e+01,
                        8.6000000e+01,8.6000000e+01,2.0898040e+02,0.0000000e+00,
                        0.0000000e+00,2.0898040e+02,2.0898040e+02,2.0898040e+02,
                        5.4440000e+02,0.0000000e+00,0.0000000e+00,5.4440000e+02,
                        5.4440000e+02,5.4440000e+02,1.5000000e+01,0.0000000e+00,
                        0.0000000e+00,1.5000000e+01,1.5000000e+01,1.5000000e+01,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.4800000e+02,0.0000000e+00,
                        0.0000000e+00,1.4800000e+02,1.4800000e+02,1.4800000e+02,
                        2.0200000e+00,0.0000000e+00,0.0000000e+00,2.0200000e+00,
                        2.0200000e+00,2.0200000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,2.9000000e+01,0.0000000e+00,
                        0.0000000e+00,2.9000000e+01,2.9000000e+01,2.9000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,3.2950000e+01,0.0000000e+00,
                        0.0000000e+00,3.2950000e+01,3.2950000e+01,3.2950000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.2000000e+01,0.0000000e+00,0.0000000e+00,1.2000000e+01,
                        1.2000000e+01,1.2000000e+01,6.8965517e-02,1.0344828e-01,
                        3.4482759e-01,4.8275862e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,8.4000000e+01,0.0000000e+00,
                        0.0000000e+00,8.4000000e+01,8.4000000e+01,8.4000000e+01,
                        9.1000000e+01,0.0000000e+00,0.0000000e+00,9.1000000e+01,
                        9.1000000e+01,9.1000000e+01,2.0900000e+02,0.0000000e+00,
                        0.0000000e+00,2.0900000e+02,2.0900000e+02,2.0900000e+02,
                        5.2700000e+02,0.0000000e+00,0.0000000e+00,5.2700000e+02,
                        5.2700000e+02,5.2700000e+02,1.6000000e+01,0.0000000e+00,
                        0.0000000e+00,1.6000000e+01,1.6000000e+01,1.6000000e+01,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.4000000e+02,0.0000000e+00,
                        0.0000000e+00,1.4000000e+02,1.4000000e+02,1.4000000e+02,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,3.0000000e+01,0.0000000e+00,
                        0.0000000e+00,3.0000000e+01,3.0000000e+01,3.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,3.8731250e+01,0.0000000e+00,
                        0.0000000e+00,3.8731250e+01,3.8731250e+01,3.8731250e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2100000e+02,0.0000000e+00,0.0000000e+00,2.2100000e+02,
                        2.2100000e+02,2.2100000e+02,6.6666667e-02,1.3333333e-01,
                        3.3333333e-01,4.6666667e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,8.5000000e+01,0.0000000e+00,
                        0.0000000e+00,8.5000000e+01,8.5000000e+01,8.5000000e+01,
                        9.7000000e+01,0.0000000e+00,0.0000000e+00,9.7000000e+01,
                        9.7000000e+01,9.7000000e+01,2.1000000e+02,0.0000000e+00,
                        0.0000000e+00,2.1000000e+02,2.1000000e+02,2.1000000e+02,
                        5.7500000e+02,0.0000000e+00,0.0000000e+00,5.7500000e+02,
                        5.7500000e+02,5.7500000e+02,1.7000000e+01,0.0000000e+00,
                        0.0000000e+00,1.7000000e+01,1.7000000e+01,1.7000000e+01,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.5000000e+02,0.0000000e+00,
                        0.0000000e+00,1.5000000e+02,1.5000000e+02,1.5000000e+02,
                        2.2000000e+00,0.0000000e+00,0.0000000e+00,2.2000000e+00,
                        2.2000000e+00,2.2000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,3.1000000e+01,0.0000000e+00,
                        0.0000000e+00,3.1000000e+01,3.1000000e+01,3.1000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,3.8731250e+01,0.0000000e+00,
                        0.0000000e+00,3.8731250e+01,3.8731250e+01,3.8731250e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),6.4516129e-02,1.6129032e-01,
                        3.2258065e-01,4.5161290e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,8.6000000e+01,0.0000000e+00,
                        0.0000000e+00,8.6000000e+01,8.6000000e+01,8.6000000e+01,
                        1.0300000e+02,0.0000000e+00,0.0000000e+00,1.0300000e+02,
                        1.0300000e+02,1.0300000e+02,2.2200000e+02,0.0000000e+00,
                        0.0000000e+00,2.2200000e+02,2.2200000e+02,2.2200000e+02,
                        2.0200000e+02,0.0000000e+00,0.0000000e+00,2.0200000e+02,
                        2.0200000e+02,2.0200000e+02,1.8000000e+01,0.0000000e+00,
                        0.0000000e+00,1.8000000e+01,1.8000000e+01,1.8000000e+01,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.5000000e+02,0.0000000e+00,
                        0.0000000e+00,1.5000000e+02,1.5000000e+02,1.5000000e+02,
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,3.2000000e+01,0.0000000e+00,
                        0.0000000e+00,3.2000000e+01,3.2000000e+01,3.2000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.8731250e+01,0.0000000e+00,
                        0.0000000e+00,3.8731250e+01,3.8731250e+01,3.8731250e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),6.2500000e-02,1.8750000e-01,
                        3.1250000e-01,4.3750000e-01,0.0000000e+00,float('nan'),
                        float('nan')],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,8.7000000e+01,0.0000000e+00,
                        0.0000000e+00,8.7000000e+01,8.7000000e+01,8.7000000e+01,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,2.2300000e+02,0.0000000e+00,
                        0.0000000e+00,2.2300000e+02,2.2300000e+02,2.2300000e+02,
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,2.6000000e+02,0.0000000e+00,
                        0.0000000e+00,2.6000000e+02,2.6000000e+02,2.6000000e+02,
                        7.0000000e-01,0.0000000e+00,0.0000000e+00,7.0000000e-01,
                        7.0000000e-01,7.0000000e-01,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,3.8731250e+01,0.0000000e+00,
                        0.0000000e+00,3.8731250e+01,3.8731250e+01,3.8731250e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,8.8000000e+01,0.0000000e+00,
                        0.0000000e+00,8.8000000e+01,8.8000000e+01,8.8000000e+01,
                        1.0000000e+01,0.0000000e+00,0.0000000e+00,1.0000000e+01,
                        1.0000000e+01,1.0000000e+01,2.2600000e+02,0.0000000e+00,
                        0.0000000e+00,2.2600000e+02,2.2600000e+02,2.2600000e+02,
                        9.7300000e+02,0.0000000e+00,0.0000000e+00,9.7300000e+02,
                        9.7300000e+02,9.7300000e+02,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,2.2100000e+02,0.0000000e+00,
                        0.0000000e+00,2.2100000e+02,2.2100000e+02,2.2100000e+02,
                        9.0000000e-01,0.0000000e+00,0.0000000e+00,9.0000000e-01,
                        9.0000000e-01,9.0000000e-01,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.8731250e+01,0.0000000e+00,
                        0.0000000e+00,3.8731250e+01,3.8731250e+01,3.8731250e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2900000e+02,0.0000000e+00,0.0000000e+00,2.2900000e+02,
                        2.2900000e+02,2.2900000e+02,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,8.9000000e+01,0.0000000e+00,
                        0.0000000e+00,8.9000000e+01,8.9000000e+01,8.9000000e+01,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,2.2700000e+02,0.0000000e+00,
                        0.0000000e+00,2.2700000e+02,2.2700000e+02,2.2700000e+02,
                        1.3230000e+03,0.0000000e+00,0.0000000e+00,1.3230000e+03,
                        1.3230000e+03,1.3230000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,2.1500000e+02,0.0000000e+00,
                        0.0000000e+00,2.1500000e+02,2.1500000e+02,2.1500000e+02,
                        1.1000000e+00,0.0000000e+00,0.0000000e+00,1.1000000e+00,
                        1.1000000e+00,1.1000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,4.4512500e+01,0.0000000e+00,
                        0.0000000e+00,4.4512500e+01,4.4512500e+01,4.4512500e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,6.6666667e-01,0.0000000e+00,
                        3.3333333e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,9.0000000e+01,0.0000000e+00,
                        0.0000000e+00,9.0000000e+01,9.0000000e+01,9.0000000e+01,
                        1.6000000e+01,0.0000000e+00,0.0000000e+00,1.6000000e+01,
                        1.6000000e+01,1.6000000e+01,2.3203806e+02,0.0000000e+00,
                        0.0000000e+00,2.3203806e+02,2.3203806e+02,2.3203806e+02,
                        2.0230000e+03,0.0000000e+00,0.0000000e+00,2.0230000e+03,
                        2.0230000e+03,2.0230000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,2.0600000e+02,0.0000000e+00,
                        0.0000000e+00,2.0600000e+02,2.0600000e+02,2.0600000e+02,
                        1.3000000e+00,0.0000000e+00,0.0000000e+00,1.3000000e+00,
                        1.3000000e+00,1.3000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,4.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        8.0000000e+00,0.0000000e+00,0.0000000e+00,8.0000000e+00,
                        8.0000000e+00,8.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        8.0000000e+00,0.0000000e+00,0.0000000e+00,8.0000000e+00,
                        8.0000000e+00,8.0000000e+00,3.2370000e+01,0.0000000e+00,
                        0.0000000e+00,3.2370000e+01,3.2370000e+01,3.2370000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        2.2500000e+02,0.0000000e+00,0.0000000e+00,2.2500000e+02,
                        2.2500000e+02,2.2500000e+02,5.0000000e-01,0.0000000e+00,
                        5.0000000e-01,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,9.1000000e+01,0.0000000e+00,
                        0.0000000e+00,9.1000000e+01,9.1000000e+01,9.1000000e+01,
                        1.8000000e+01,0.0000000e+00,0.0000000e+00,1.8000000e+01,
                        1.8000000e+01,1.8000000e+01,2.3103586e+02,0.0000000e+00,
                        0.0000000e+00,2.3103586e+02,2.3103586e+02,2.3103586e+02,
                        1.8450000e+03,0.0000000e+00,0.0000000e+00,1.8450000e+03,
                        1.8450000e+03,1.8450000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,2.0000000e+02,0.0000000e+00,
                        0.0000000e+00,2.0000000e+02,2.0000000e+02,2.0000000e+02,
                        1.5000000e+00,0.0000000e+00,0.0000000e+00,1.5000000e+00,
                        1.5000000e+00,1.5000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,1.2000000e+01,0.0000000e+00,
                        0.0000000e+00,1.2000000e+01,1.2000000e+01,1.2000000e+01,
                        2.1000000e+01,0.0000000e+00,0.0000000e+00,2.1000000e+01,
                        2.1000000e+01,2.1000000e+01,2.5180000e+01,0.0000000e+00,
                        0.0000000e+00,2.5180000e+01,2.5180000e+01,2.5180000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.3900000e+02,0.0000000e+00,0.0000000e+00,1.3900000e+02,
                        1.3900000e+02,1.3900000e+02,4.0000000e-01,0.0000000e+00,
                        2.0000000e-01,4.0000000e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,9.2000000e+01,0.0000000e+00,
                        0.0000000e+00,9.2000000e+01,9.2000000e+01,9.2000000e+01,
                        2.0000000e+01,0.0000000e+00,0.0000000e+00,2.0000000e+01,
                        2.0000000e+01,2.0000000e+01,2.3802891e+02,0.0000000e+00,
                        0.0000000e+00,2.3802891e+02,2.3802891e+02,2.3802891e+02,
                        1.4080000e+03,0.0000000e+00,0.0000000e+00,1.4080000e+03,
                        1.4080000e+03,1.4080000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,1.9600000e+02,0.0000000e+00,
                        0.0000000e+00,1.9600000e+02,1.9600000e+02,1.9600000e+02,
                        1.3800000e+00,0.0000000e+00,0.0000000e+00,1.3800000e+00,
                        1.3800000e+00,1.3800000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,6.0000000e+00,0.0000000e+00,
                        0.0000000e+00,6.0000000e+00,6.0000000e+00,6.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,1.1000000e+01,0.0000000e+00,
                        0.0000000e+00,1.1000000e+01,1.1000000e+01,1.1000000e+01,
                        2.0000000e+01,0.0000000e+00,0.0000000e+00,2.0000000e+01,
                        2.0000000e+01,2.0000000e+01,2.0025000e+01,0.0000000e+00,
                        0.0000000e+00,2.0025000e+01,2.0025000e+01,2.0025000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        6.3000000e+01,0.0000000e+00,0.0000000e+00,6.3000000e+01,
                        6.3000000e+01,6.3000000e+01,3.3333333e-01,0.0000000e+00,
                        1.6666667e-01,5.0000000e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,9.3000000e+01,0.0000000e+00,
                        0.0000000e+00,9.3000000e+01,9.3000000e+01,9.3000000e+01,
                        2.2000000e+01,0.0000000e+00,0.0000000e+00,2.2000000e+01,
                        2.2000000e+01,2.2000000e+01,2.3700000e+02,0.0000000e+00,
                        0.0000000e+00,2.3700000e+02,2.3700000e+02,2.3700000e+02,
                        9.1700000e+02,0.0000000e+00,0.0000000e+00,9.1700000e+02,
                        9.1700000e+02,9.1700000e+02,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,1.9000000e+02,0.0000000e+00,
                        0.0000000e+00,1.9000000e+02,1.9000000e+02,1.9000000e+02,
                        1.3600000e+00,0.0000000e+00,0.0000000e+00,1.3600000e+00,
                        1.3600000e+00,1.3600000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,7.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        1.9000000e+01,0.0000000e+00,0.0000000e+00,1.9000000e+01,
                        1.9000000e+01,1.9000000e+01,1.8453750e+01,0.0000000e+00,
                        0.0000000e+00,1.8453750e+01,1.8453750e+01,1.8453750e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        6.2000000e+01,0.0000000e+00,0.0000000e+00,6.2000000e+01,
                        6.2000000e+01,6.2000000e+01,2.8571429e-01,0.0000000e+00,
                        1.4285714e-01,5.7142857e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,9.4000000e+01,0.0000000e+00,
                        0.0000000e+00,9.4000000e+01,9.4000000e+01,9.4000000e+01,
                        2.4000000e+01,0.0000000e+00,0.0000000e+00,2.4000000e+01,
                        2.4000000e+01,2.4000000e+01,2.4400000e+02,0.0000000e+00,
                        0.0000000e+00,2.4400000e+02,2.4400000e+02,2.4400000e+02,
                        9.1300000e+02,0.0000000e+00,0.0000000e+00,9.1300000e+02,
                        9.1300000e+02,9.1300000e+02,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,1.8700000e+02,0.0000000e+00,
                        0.0000000e+00,1.8700000e+02,1.8700000e+02,1.8700000e+02,
                        1.2800000e+00,0.0000000e+00,0.0000000e+00,1.2800000e+00,
                        1.2800000e+00,1.2800000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,8.0000000e+00,0.0000000e+00,
                        0.0000000e+00,8.0000000e+00,8.0000000e+00,8.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,8.0000000e+00,0.0000000e+00,
                        0.0000000e+00,8.0000000e+00,8.0000000e+00,8.0000000e+00,
                        8.0000000e+00,0.0000000e+00,0.0000000e+00,8.0000000e+00,
                        8.0000000e+00,8.0000000e+00,1.8080000e+01,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,1.8080000e+01,1.8080000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.1800364e-01,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,3.1800364e-01,3.1800364e-01,
                        1.1000000e+01,0.0000000e+00,0.0000000e+00,1.1000000e+01,
                        1.1000000e+01,1.1000000e+01,2.5000000e-01,0.0000000e+00,
                        0.0000000e+00,7.5000000e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,9.5000000e+01,0.0000000e+00,
                        0.0000000e+00,9.5000000e+01,9.5000000e+01,9.5000000e+01,
                        2.6000000e+01,0.0000000e+00,0.0000000e+00,2.6000000e+01,
                        2.6000000e+01,2.6000000e+01,2.4300000e+02,0.0000000e+00,
                        0.0000000e+00,2.4300000e+02,2.4300000e+02,2.4300000e+02,
                        1.4490000e+03,0.0000000e+00,0.0000000e+00,1.4490000e+03,
                        1.4490000e+03,1.4490000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,1.8000000e+02,0.0000000e+00,
                        0.0000000e+00,1.8000000e+02,1.8000000e+02,1.8000000e+02,
                        1.3000000e+00,0.0000000e+00,0.0000000e+00,1.3000000e+00,
                        1.3000000e+00,1.3000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,9.0000000e+00,0.0000000e+00,
                        0.0000000e+00,9.0000000e+00,9.0000000e+00,9.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,7.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,1.8080000e+01,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,1.8080000e+01,1.8080000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.1800364e-01,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,3.1800364e-01,3.1800364e-01,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,2.2222222e-01,0.0000000e+00,
                        0.0000000e+00,7.7777778e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,9.6000000e+01,0.0000000e+00,
                        0.0000000e+00,9.6000000e+01,9.6000000e+01,9.6000000e+01,
                        2.8000000e+01,0.0000000e+00,0.0000000e+00,2.8000000e+01,
                        2.8000000e+01,2.8000000e+01,2.4700000e+02,0.0000000e+00,
                        0.0000000e+00,2.4700000e+02,2.4700000e+02,2.4700000e+02,
                        1.6180000e+03,0.0000000e+00,0.0000000e+00,1.6180000e+03,
                        1.6180000e+03,1.6180000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,1.6900000e+02,0.0000000e+00,
                        0.0000000e+00,1.6900000e+02,1.6900000e+02,1.6900000e+02,
                        1.3000000e+00,0.0000000e+00,0.0000000e+00,1.3000000e+00,
                        1.3000000e+00,1.3000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,7.0000000e+00,
                        1.6000000e+01,0.0000000e+00,0.0000000e+00,1.6000000e+01,
                        1.6000000e+01,1.6000000e+01,1.8080000e+01,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,1.8080000e+01,1.8080000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.1800364e-01,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,3.1800364e-01,3.1800364e-01,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,2.0000000e-01,0.0000000e+00,
                        1.0000000e-01,7.0000000e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,9.7000000e+01,0.0000000e+00,
                        0.0000000e+00,9.7000000e+01,9.7000000e+01,9.7000000e+01,
                        3.0000000e+01,0.0000000e+00,0.0000000e+00,3.0000000e+01,
                        3.0000000e+01,3.0000000e+01,2.4700000e+02,0.0000000e+00,
                        0.0000000e+00,2.4700000e+02,2.4700000e+02,2.4700000e+02,
                        1.3230000e+03,0.0000000e+00,0.0000000e+00,1.3230000e+03,
                        1.3230000e+03,1.3230000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        1.3000000e+00,0.0000000e+00,0.0000000e+00,1.3000000e+00,
                        1.3000000e+00,1.3000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        9.0000000e+00,0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,1.1000000e+01,0.0000000e+00,
                        0.0000000e+00,1.1000000e+01,1.1000000e+01,1.1000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.8080000e+01,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,1.8080000e+01,1.8080000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.1800364e-01,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,3.1800364e-01,3.1800364e-01,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,1.8181818e-01,0.0000000e+00,
                        0.0000000e+00,8.1818182e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,9.8000000e+01,0.0000000e+00,
                        0.0000000e+00,9.8000000e+01,9.8000000e+01,9.8000000e+01,
                        3.2000000e+01,0.0000000e+00,0.0000000e+00,3.2000000e+01,
                        3.2000000e+01,3.2000000e+01,2.5100000e+02,0.0000000e+00,
                        0.0000000e+00,2.5100000e+02,2.5100000e+02,2.5100000e+02,
                        1.1730000e+03,0.0000000e+00,0.0000000e+00,1.1730000e+03,
                        1.1730000e+03,1.1730000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        1.3000000e+00,0.0000000e+00,0.0000000e+00,1.3000000e+00,
                        1.3000000e+00,1.3000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.0000000e+01,0.0000000e+00,0.0000000e+00,1.0000000e+01,
                        1.0000000e+01,1.0000000e+01,1.2000000e+01,0.0000000e+00,
                        0.0000000e+00,1.2000000e+01,1.2000000e+01,1.2000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,4.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,1.8080000e+01,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,1.8080000e+01,1.8080000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.1800364e-01,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,3.1800364e-01,3.1800364e-01,
                        1.9400000e+02,0.0000000e+00,0.0000000e+00,1.9400000e+02,
                        1.9400000e+02,1.9400000e+02,1.6666667e-01,0.0000000e+00,
                        0.0000000e+00,8.3333333e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,9.9000000e+01,0.0000000e+00,
                        0.0000000e+00,9.9000000e+01,9.9000000e+01,9.9000000e+01,
                        3.4000000e+01,0.0000000e+00,0.0000000e+00,3.4000000e+01,
                        3.4000000e+01,3.4000000e+01,2.5200000e+02,0.0000000e+00,
                        0.0000000e+00,2.5200000e+02,2.5200000e+02,2.5200000e+02,
                        1.1330000e+03,0.0000000e+00,0.0000000e+00,1.1330000e+03,
                        1.1330000e+03,1.1330000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        1.3000000e+00,0.0000000e+00,0.0000000e+00,1.3000000e+00,
                        1.3000000e+00,1.3000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.1000000e+01,0.0000000e+00,0.0000000e+00,1.1000000e+01,
                        1.1000000e+01,1.1000000e+01,1.3000000e+01,0.0000000e+00,
                        0.0000000e+00,1.3000000e+01,1.3000000e+01,1.3000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,3.0000000e+00,
                        3.0000000e+00,3.0000000e+00,1.8080000e+01,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,1.8080000e+01,1.8080000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.1800364e-01,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,3.1800364e-01,3.1800364e-01,
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),1.5384615e-01,0.0000000e+00,
                        0.0000000e+00,8.4615385e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.0000000e+02,0.0000000e+00,
                        0.0000000e+00,1.0000000e+02,1.0000000e+02,1.0000000e+02,
                        3.6000000e+01,0.0000000e+00,0.0000000e+00,3.6000000e+01,
                        3.6000000e+01,3.6000000e+01,2.5700000e+02,0.0000000e+00,
                        0.0000000e+00,2.5700000e+02,2.5700000e+02,2.5700000e+02,
                        1.8000000e+03,0.0000000e+00,0.0000000e+00,1.8000000e+03,
                        1.8000000e+03,1.8000000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        1.3000000e+00,0.0000000e+00,0.0000000e+00,1.3000000e+00,
                        1.3000000e+00,1.3000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.2000000e+01,0.0000000e+00,0.0000000e+00,1.2000000e+01,
                        1.2000000e+01,1.2000000e+01,1.4000000e+01,0.0000000e+00,
                        0.0000000e+00,1.4000000e+01,1.4000000e+01,1.4000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,2.0000000e+00,
                        2.0000000e+00,2.0000000e+00,1.8080000e+01,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,1.8080000e+01,1.8080000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.1800364e-01,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,3.1800364e-01,3.1800364e-01,
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),1.4285714e-01,0.0000000e+00,
                        0.0000000e+00,8.5714286e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.0100000e+02,0.0000000e+00,
                        0.0000000e+00,1.0100000e+02,1.0100000e+02,1.0100000e+02,
                        3.8000000e+01,0.0000000e+00,0.0000000e+00,3.8000000e+01,
                        3.8000000e+01,3.8000000e+01,2.5800000e+02,0.0000000e+00,
                        0.0000000e+00,2.5800000e+02,2.5800000e+02,2.5800000e+02,
                        1.1000000e+03,0.0000000e+00,0.0000000e+00,1.1000000e+03,
                        1.1000000e+03,1.1000000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        1.3000000e+00,0.0000000e+00,0.0000000e+00,1.3000000e+00,
                        1.3000000e+00,1.3000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.3000000e+01,0.0000000e+00,0.0000000e+00,1.3000000e+01,
                        1.3000000e+01,1.3000000e+01,1.5000000e+01,0.0000000e+00,
                        0.0000000e+00,1.5000000e+01,1.5000000e+01,1.5000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.8080000e+01,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,1.8080000e+01,1.8080000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.1800364e-01,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,3.1800364e-01,3.1800364e-01,
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),1.3333333e-01,0.0000000e+00,
                        0.0000000e+00,8.6666667e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.0200000e+02,0.0000000e+00,
                        0.0000000e+00,1.0200000e+02,1.0200000e+02,1.0200000e+02,
                        4.0000000e+01,0.0000000e+00,0.0000000e+00,4.0000000e+01,
                        4.0000000e+01,4.0000000e+01,2.5900000e+02,0.0000000e+00,
                        0.0000000e+00,2.5900000e+02,2.5900000e+02,2.5900000e+02,
                        1.1000000e+03,0.0000000e+00,0.0000000e+00,1.1000000e+03,
                        1.1000000e+03,1.1000000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        1.3000000e+00,0.0000000e+00,0.0000000e+00,1.3000000e+00,
                        1.3000000e+00,1.3000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,1.6000000e+01,0.0000000e+00,
                        0.0000000e+00,1.6000000e+01,1.6000000e+01,1.6000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,1.8080000e+01,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,1.8080000e+01,1.8080000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.1800364e-01,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,3.1800364e-01,3.1800364e-01,
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),1.2500000e-01,0.0000000e+00,
                        0.0000000e+00,8.7500000e-01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.0300000e+02,0.0000000e+00,
                        0.0000000e+00,1.0300000e+02,1.0300000e+02,1.0300000e+02,
                        4.2000000e+01,0.0000000e+00,0.0000000e+00,4.2000000e+01,
                        4.2000000e+01,4.2000000e+01,2.6200000e+02,0.0000000e+00,
                        0.0000000e+00,2.6200000e+02,2.6200000e+02,2.6200000e+02,
                        1.9000000e+03,0.0000000e+00,0.0000000e+00,1.9000000e+03,
                        1.9000000e+03,1.9000000e+03,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,3.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,2.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        1.4000000e+01,0.0000000e+00,0.0000000e+00,1.4000000e+01,
                        1.4000000e+01,1.4000000e+01,1.7000000e+01,0.0000000e+00,
                        0.0000000e+00,1.7000000e+01,1.7000000e+01,1.7000000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,5.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,1.8080000e+01,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,1.8080000e+01,1.8080000e+01,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,3.1800364e-01,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,3.1800364e-01,3.1800364e-01,
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),1.1764706e-01,5.8823529e-02,
                        0.0000000e+00,8.2352941e-01,0.0000000e+00,float('nan'),
                        float('nan')],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0400000e+02,0.0000000e+00,0.0000000e+00,
                        1.0400000e+02,1.0400000e+02,1.0400000e+02,float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),2.6500000e+02,0.0000000e+00,
                        0.0000000e+00,2.6500000e+02,2.6500000e+02,
                        2.6500000e+02,float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),4.0000000e+00,
                        0.0000000e+00,0.0000000e+00,4.0000000e+00,
                        4.0000000e+00,4.0000000e+00,7.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,
                        2.0000000e+00,1.4000000e+01,0.0000000e+00,
                        0.0000000e+00,1.4000000e+01,1.4000000e+01,
                        1.4000000e+01,1.8000000e+01,0.0000000e+00,
                        0.0000000e+00,1.8000000e+01,1.8000000e+01,
                        1.8000000e+01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,8.0000000e+00,0.0000000e+00,
                        0.0000000e+00,8.0000000e+00,8.0000000e+00,
                        8.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,8.0000000e+00,0.0000000e+00,
                        0.0000000e+00,8.0000000e+00,8.0000000e+00,
                        8.0000000e+00,1.8080000e+01,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,1.8080000e+01,
                        1.8080000e+01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,3.1800364e-01,
                        3.1800364e-01,float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),1.1111111e-01,
                        0.0000000e+00,1.1111111e-01,7.7777778e-01,
                        0.0000000e+00,float('nan'),float('nan')],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0500000e+02,0.0000000e+00,0.0000000e+00,
                        1.0500000e+02,1.0500000e+02,1.0500000e+02,float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),2.6800000e+02,0.0000000e+00,
                        0.0000000e+00,2.6800000e+02,2.6800000e+02,
                        2.6800000e+02,float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),5.0000000e+00,
                        0.0000000e+00,0.0000000e+00,5.0000000e+00,
                        5.0000000e+00,5.0000000e+00,7.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,
                        3.0000000e+00,1.4000000e+01,0.0000000e+00,
                        0.0000000e+00,1.4000000e+01,1.4000000e+01,
                        1.4000000e+01,1.9000000e+01,0.0000000e+00,
                        0.0000000e+00,1.9000000e+01,1.9000000e+01,
                        1.9000000e+01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,
                        7.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,
                        7.0000000e+00,1.8080000e+01,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,1.8080000e+01,
                        1.8080000e+01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,3.1800364e-01,
                        3.1800364e-01,float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),1.0526316e-01,
                        0.0000000e+00,1.5789474e-01,7.3684211e-01,
                        0.0000000e+00,float('nan'),float('nan')],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0600000e+02,0.0000000e+00,0.0000000e+00,
                        1.0600000e+02,1.0600000e+02,1.0600000e+02,float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),2.7100000e+02,0.0000000e+00,
                        0.0000000e+00,2.7100000e+02,2.7100000e+02,
                        2.7100000e+02,float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),6.0000000e+00,
                        0.0000000e+00,0.0000000e+00,6.0000000e+00,
                        6.0000000e+00,6.0000000e+00,7.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,
                        4.0000000e+00,1.4000000e+01,0.0000000e+00,
                        0.0000000e+00,1.4000000e+01,1.4000000e+01,
                        1.4000000e+01,2.0000000e+01,0.0000000e+00,
                        0.0000000e+00,2.0000000e+01,2.0000000e+01,
                        2.0000000e+01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,6.0000000e+00,0.0000000e+00,
                        0.0000000e+00,6.0000000e+00,6.0000000e+00,
                        6.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,6.0000000e+00,0.0000000e+00,
                        0.0000000e+00,6.0000000e+00,6.0000000e+00,
                        6.0000000e+00,1.8080000e+01,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,1.8080000e+01,
                        1.8080000e+01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,3.1800364e-01,
                        3.1800364e-01,float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),1.0000000e-01,
                        0.0000000e+00,2.0000000e-01,7.0000000e-01,
                        0.0000000e+00,float('nan'),float('nan')],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0700000e+02,0.0000000e+00,0.0000000e+00,
                        1.0700000e+02,1.0700000e+02,1.0700000e+02,float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),2.7200000e+02,0.0000000e+00,
                        0.0000000e+00,2.7200000e+02,2.7200000e+02,
                        2.7200000e+02,float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),7.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,7.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,
                        5.0000000e+00,1.4000000e+01,0.0000000e+00,
                        0.0000000e+00,1.4000000e+01,1.4000000e+01,
                        1.4000000e+01,2.1000000e+01,0.0000000e+00,
                        0.0000000e+00,2.1000000e+01,2.1000000e+01,
                        2.1000000e+01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,
                        5.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,0.0000000e+00,
                        0.0000000e+00,5.0000000e+00,5.0000000e+00,
                        5.0000000e+00,1.8080000e+01,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,1.8080000e+01,
                        1.8080000e+01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,3.1800364e-01,
                        3.1800364e-01,float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),9.5238095e-02,
                        0.0000000e+00,2.3809524e-01,6.6666667e-01,
                        0.0000000e+00,float('nan'),float('nan')],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0800000e+02,0.0000000e+00,0.0000000e+00,
                        1.0800000e+02,1.0800000e+02,1.0800000e+02,float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),2.7000000e+02,0.0000000e+00,
                        0.0000000e+00,2.7000000e+02,2.7000000e+02,
                        2.7000000e+02,float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),8.0000000e+00,
                        0.0000000e+00,0.0000000e+00,8.0000000e+00,
                        8.0000000e+00,8.0000000e+00,7.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,6.0000000e+00,0.0000000e+00,
                        0.0000000e+00,6.0000000e+00,6.0000000e+00,
                        6.0000000e+00,1.4000000e+01,0.0000000e+00,
                        0.0000000e+00,1.4000000e+01,1.4000000e+01,
                        1.4000000e+01,2.2000000e+01,0.0000000e+00,
                        0.0000000e+00,2.2000000e+01,2.2000000e+01,
                        2.2000000e+01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,
                        4.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,0.0000000e+00,
                        0.0000000e+00,4.0000000e+00,4.0000000e+00,
                        4.0000000e+00,1.8080000e+01,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,1.8080000e+01,
                        1.8080000e+01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,3.1800364e-01,
                        3.1800364e-01,float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),9.0909091e-02,
                        0.0000000e+00,2.7272727e-01,6.3636364e-01,
                        0.0000000e+00,float('nan'),float('nan')],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0900000e+02,0.0000000e+00,0.0000000e+00,
                        1.0900000e+02,1.0900000e+02,1.0900000e+02,float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),2.7600000e+02,0.0000000e+00,
                        0.0000000e+00,2.7600000e+02,2.7600000e+02,
                        2.7600000e+02,float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),9.0000000e+00,
                        0.0000000e+00,0.0000000e+00,9.0000000e+00,
                        9.0000000e+00,9.0000000e+00,7.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,0.0000000e+00,
                        0.0000000e+00,7.0000000e+00,7.0000000e+00,
                        7.0000000e+00,1.4000000e+01,0.0000000e+00,
                        0.0000000e+00,1.4000000e+01,1.4000000e+01,
                        1.4000000e+01,2.3000000e+01,0.0000000e+00,
                        0.0000000e+00,2.3000000e+01,2.3000000e+01,
                        2.3000000e+01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,
                        3.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.0000000e+00,3.0000000e+00,
                        3.0000000e+00,1.8080000e+01,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,1.8080000e+01,
                        1.8080000e+01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,3.1800364e-01,
                        3.1800364e-01,float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),8.6956522e-02,
                        0.0000000e+00,3.0434783e-01,6.0869565e-01,
                        0.0000000e+00,float('nan'),float('nan')],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.1000000e+02,0.0000000e+00,0.0000000e+00,
                        1.1000000e+02,1.1000000e+02,1.1000000e+02,float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),2.8100000e+02,0.0000000e+00,
                        0.0000000e+00,2.8100000e+02,2.8100000e+02,
                        2.8100000e+02,float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),1.0000000e+01,
                        0.0000000e+00,0.0000000e+00,1.0000000e+01,
                        1.0000000e+01,1.0000000e+01,7.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,9.0000000e+00,0.0000000e+00,
                        0.0000000e+00,9.0000000e+00,9.0000000e+00,
                        9.0000000e+00,1.4000000e+01,0.0000000e+00,
                        0.0000000e+00,1.4000000e+01,1.4000000e+01,
                        1.4000000e+01,2.4000000e+01,0.0000000e+00,
                        0.0000000e+00,2.4000000e+01,2.4000000e+01,
                        2.4000000e+01,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,
                        2.0000000e+00,1.8080000e+01,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,1.8080000e+01,
                        1.8080000e+01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,3.1800364e-01,
                        3.1800364e-01,float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),4.1666667e-02,
                        0.0000000e+00,3.7500000e-01,5.8333333e-01,
                        0.0000000e+00,float('nan'),float('nan')],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.1100000e+02,0.0000000e+00,0.0000000e+00,
                        1.1100000e+02,1.1100000e+02,1.1100000e+02,float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),2.8000000e+02,0.0000000e+00,
                        0.0000000e+00,2.8000000e+02,2.8000000e+02,
                        2.8000000e+02,float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),1.1000000e+01,
                        0.0000000e+00,0.0000000e+00,1.1000000e+01,
                        1.1000000e+01,1.1000000e+01,7.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,
                        1.0000000e+01,1.4000000e+01,0.0000000e+00,
                        0.0000000e+00,1.4000000e+01,1.4000000e+01,
                        1.4000000e+01,2.5000000e+01,0.0000000e+00,
                        0.0000000e+00,2.5000000e+01,2.5000000e+01,
                        2.5000000e+01,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.8080000e+01,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,1.8080000e+01,
                        1.8080000e+01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,3.1800364e-01,
                        3.1800364e-01,float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),4.0000000e-02,
                        0.0000000e+00,4.0000000e-01,5.6000000e-01,
                        0.0000000e+00,float('nan'),float('nan')],
                       [1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.0000000e+00,1.0000000e+00,1.0000000e+00,
                        1.1200000e+02,0.0000000e+00,0.0000000e+00,
                        1.1200000e+02,1.1200000e+02,1.1200000e+02,float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),2.8500000e+02,0.0000000e+00,
                        0.0000000e+00,2.8500000e+02,2.8500000e+02,
                        2.8500000e+02,float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),1.2000000e+01,
                        0.0000000e+00,0.0000000e+00,1.2000000e+01,
                        1.2000000e+01,1.2000000e+01,7.0000000e+00,
                        0.0000000e+00,0.0000000e+00,7.0000000e+00,
                        7.0000000e+00,7.0000000e+00,float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),2.0000000e+00,0.0000000e+00,
                        0.0000000e+00,2.0000000e+00,2.0000000e+00,
                        2.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,0.0000000e+00,
                        0.0000000e+00,1.0000000e+01,1.0000000e+01,
                        1.0000000e+01,1.4000000e+01,0.0000000e+00,
                        0.0000000e+00,1.4000000e+01,1.4000000e+01,
                        1.4000000e+01,2.6000000e+01,0.0000000e+00,
                        0.0000000e+00,2.6000000e+01,2.6000000e+01,
                        2.6000000e+01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,0.0000000e+00,
                        0.0000000e+00,1.8080000e+01,1.8080000e+01,
                        1.8080000e+01,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,0.0000000e+00,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,0.0000000e+00,
                        0.0000000e+00,3.1800364e-01,3.1800364e-01,
                        3.1800364e-01,float('nan'),float('nan'),float('nan'),
                        float('nan'),float('nan'),float('nan'),7.6923077e-02,
                        0.0000000e+00,3.8461538e-01,5.3846154e-01,
                        0.0000000e+00,float('nan'),float('nan')]]

        # Check if headers are the same
        for i in xrange(len(f1_headers)):
            if (f1_headers[i] != feat_headers[i]):
                print 'Test failed spectacularly!!!'
                print i, f1_headers[i], feat_headers[i]
                sys.exit(1)

        # Check if the values are the same
        for i in xrange(len(f1_values)):
            for j in xrange(len(f1_values[i])):
                pass
            if (math.isnan(feat_values[i][j]) and math.isnan(f1_values[i][j])) \
                    or (np.isclose(f1_values[i][j], feat_values[i][j]),
                        self.rtol, self.atol, True):
                continue
            else:
                print 'Test failed spectacularly!!!'
                print i,j,f1_values[i][j],feat_values[i][j]
                sys.exit(1)

        # If code reaches this point that means, the test is successful.
        print 'Test passed successfully'


if __name__ == "__main__":
    x = Magpie()
    x.test_example()